 /*
 * Project       : ipv6calc
 * File          : dbipv4_assignment.h
 * Version       : $Id: dbipv4addr_assignment.h,v 1.5 2002/07/17 20:42:08 peter Exp $
 * Generated     : Wed Jul 17 20:54:17 2002
 * Data copyright: RIPE NCC, APNIC, ARIN
 *
 * Information:
 *  Additional header file for libipv4addr.c
 */


static const s_ipv4addr_assignment dbipv4addr_assignment[] = {
	{ 0x3d000000, 0xff000000, "APNIC" },
	{ 0xa9de0000, 0xffff8000, "APNIC" },
	{ 0xa9de8000, 0xffffe000, "APNIC" },
	{ 0xca000000, 0xfe000000, "APNIC" },
	{ 0xd2000000, 0xfe000000, "APNIC" },
	{ 0xda000000, 0xfe000000, "APNIC" },
	{ 0xdc000000, 0xfe000000, "APNIC" },
	{ 0x18840000, 0xffff0000, "RIPENCC" },
	{ 0x3e000000, 0xff000000, "RIPENCC" },
	{ 0x50000000, 0xfe000000, "RIPENCC" },
	{ 0x818e0000, 0xffff0000, "RIPENCC" },
	{ 0x82e30000, 0xffff0000, "RIPENCC" },
	{ 0x82e40000, 0xffff0000, "RIPENCC" },
	{ 0x82ed0000, 0xffff0000, "RIPENCC" },
	{ 0x82f20000, 0xfffe0000, "RIPENCC" },
	{ 0x82f40000, 0xffff0000, "RIPENCC" },
	{ 0x8d270000, 0xffff0000, "RIPENCC" },
	{ 0x91fd0000, 0xffff0000, "RIPENCC" },
	{ 0x91fe0000, 0xffff0000, "RIPENCC" },
	{ 0x93a70000, 0xffff0000, "RIPENCC" },
	{ 0x96fe0000, 0xffff0000, "RIPENCC" },
	{ 0x970b0000, 0xffff0000, "RIPENCC" },
	{ 0x970c0000, 0xffff0000, "RIPENCC" },
	{ 0x97270000, 0xffff0000, "RIPENCC" },
	{ 0x97bd0000, 0xffff0000, "RIPENCC" },
	{ 0x9d9e0000, 0xffff0000, "RIPENCC" },
	{ 0x9ee80000, 0xffff0000, "RIPENCC" },
	{ 0xa03d0000, 0xffff0000, "RIPENCC" },
	{ 0xa03e0000, 0xffff0000, "RIPENCC" },
	{ 0xa2560000, 0xffff0000, "RIPENCC" },
	{ 0xa4800000, 0xffff0000, "RIPENCC" },
	{ 0xaa3c0000, 0xffff0000, "RIPENCC" },
	{ 0xaaec0000, 0xfffe0000, "RIPENCC" },
	{ 0xc0240000, 0xfffe0000, "RIPENCC" },
	{ 0xc0268000, 0xffff8000, "RIPENCC" },
	{ 0xc0470000, 0xffff0000, "RIPENCC" },
	{ 0xc0590000, 0xffff0000, "RIPENCC" },
	{ 0xc06a0000, 0xffff0000, "RIPENCC" },
	{ 0xc0790000, 0xffff0000, "RIPENCC" },
	{ 0xc0820000, 0xffff0000, "RIPENCC" },
	{ 0xc0a40000, 0xfffe0000, "RIPENCC" },
	{ 0xc0a70000, 0xffff0000, "RIPENCC" },
	{ 0xc0b00000, 0xffff0000, "RIPENCC" },
	{ 0xc0c20000, 0xffff0000, "RIPENCC" },
	{ 0xc1000000, 0xff000000, "RIPENCC" },
	{ 0xc2000000, 0xfe000000, "RIPENCC" },
	{ 0xd4000000, 0xfe000000, "RIPENCC" },
	{ 0xd9000000, 0xff000000, "RIPENCC" },
	{ 0x03000000, 0xff000000, "ARIN" },
	{ 0x04000000, 0xff000000, "ARIN" },
	{ 0x06000000, 0xff000000, "ARIN" },
	{ 0x08000000, 0xfe000000, "ARIN" },
	{ 0x0b000000, 0xff000000, "ARIN" },
	{ 0x0c000000, 0xfe000000, "ARIN" },
	{ 0x0f000000, 0xff000000, "ARIN" },
	{ 0x10000000, 0xfc000000, "ARIN" },
	{ 0x14000000, 0xfe000000, "ARIN" },
	{ 0x16000000, 0xff000000, "ARIN" },
	{ 0x18000000, 0xfe000000, "ARIN" },
	{ 0x1a000000, 0xff000000, "ARIN" },
	{ 0x1c000000, 0xfe000000, "ARIN" },
	{ 0x1e000000, 0xff000000, "ARIN" },
	{ 0x20000000, 0xfc000000, "ARIN" },
	{ 0x26000000, 0xff000000, "ARIN" },
	{ 0x28000000, 0xff000000, "ARIN" },
	{ 0x2b000000, 0xff000000, "ARIN" },
	{ 0x2c000000, 0xfe000000, "ARIN" },
	{ 0x2f000000, 0xff000000, "ARIN" },
	{ 0x30000000, 0xff000000, "ARIN" },
	{ 0x33000000, 0xff000000, "ARIN" },
	{ 0x34000000, 0xfc000000, "ARIN" },
	{ 0x38000000, 0xfe000000, "ARIN" },
	{ 0x3f000000, 0xff000000, "ARIN" },
	{ 0x40000000, 0xfc000000, "ARIN" },
	{ 0x44000000, 0xff000000, "ARIN" },
	{ 0x80000000, 0xffe00000, "ARIN" },
	{ 0x80200000, 0xfff80000, "ARIN" },
	{ 0x80280000, 0xfffc0000, "ARIN" },
	{ 0x802c0000, 0xffff0000, "ARIN" },
	{ 0x802e0000, 0xfffe0000, "ARIN" },
	{ 0x80300000, 0xfff00000, "ARIN" },
	{ 0x80400000, 0xffff0000, "ARIN" },
	{ 0x80420000, 0xffff0000, "ARIN" },
	{ 0x80500000, 0xfff00000, "ARIN" },
	{ 0x80600000, 0xfff00000, "ARIN" },
	{ 0x80700000, 0xfff80000, "ARIN" },
	{ 0x80780000, 0xfffc0000, "ARIN" },
	{ 0x807d0000, 0xffff0000, "ARIN" },
	{ 0x807e0000, 0xfffe0000, "ARIN" },
	{ 0x80800000, 0xfff80000, "ARIN" },
	{ 0x80880000, 0xfffc0000, "ARIN" },
	{ 0x808f0000, 0xffff0000, "ARIN" },
	{ 0x80900000, 0xfff00000, "ARIN" },
	{ 0x80a00000, 0xffe00000, "ARIN" },
	{ 0x80c00000, 0xfffc0000, "ARIN" },
	{ 0x80c40000, 0xfffe0000, "ARIN" },
	{ 0x80c60000, 0xffff0000, "ARIN" },
	{ 0x80c80000, 0xffff0000, "ARIN" },
	{ 0x80ca0000, 0xfffe0000, "ARIN" },
	{ 0x80cd0000, 0xffff0000, "ARIN" },
	{ 0x80ce0000, 0xfffe0000, "ARIN" },
	{ 0x80d00000, 0xfff00000, "ARIN" },
	{ 0x80e00000, 0xfff80000, "ARIN" },
	{ 0x80e80000, 0xfffe0000, "ARIN" },
	{ 0x80eb0000, 0xffff0000, "ARIN" },
	{ 0x80ec0000, 0xfffc0000, "ARIN" },
	{ 0x80f00000, 0xfff00000, "ARIN" },
	{ 0x81010000, 0xffff0000, "ARIN" },
	{ 0x81020000, 0xfffe0000, "ARIN" },
	{ 0x81040000, 0xfffc0000, "ARIN" },
	{ 0x81080000, 0xfff80000, "ARIN" },
	{ 0x81100000, 0xfffe0000, "ARIN" },
	{ 0x81130000, 0xffff0000, "ARIN" },
	{ 0x81140000, 0xfffc0000, "ARIN" },
	{ 0x81180000, 0xfff80000, "ARIN" },
	{ 0x81200000, 0xfff80000, "ARIN" },
	{ 0x81280000, 0xfffc0000, "ARIN" },
	{ 0x812c0000, 0xffff0000, "ARIN" },
	{ 0x812e0000, 0xfffe0000, "ARIN" },
	{ 0x81300000, 0xfff80000, "ARIN" },
	{ 0x81390000, 0xffff0000, "ARIN" },
	{ 0x813a0000, 0xfffe0000, "ARIN" },
	{ 0x813c0000, 0xfffc0000, "ARIN" },
	{ 0x81400000, 0xffc00000, "ARIN" },
	{ 0x81800000, 0xfff80000, "ARIN" },
	{ 0x81880000, 0xfffc0000, "ARIN" },
	{ 0x818d0000, 0xffff0000, "ARIN" },
	{ 0x818f0000, 0xffff0000, "ARIN" },
	{ 0x81900000, 0xfff00000, "ARIN" },
	{ 0x81a00000, 0xffe00000, "ARIN" },
	{ 0x81c00000, 0xfff80000, "ARIN" },
	{ 0x81c80000, 0xfffe0000, "ARIN" },
	{ 0x81cb0000, 0xffff0000, "ARIN" },
	{ 0x81cc0000, 0xffff0000, "ARIN" },
	{ 0x81ce0000, 0xfffe0000, "ARIN" },
	{ 0x81d00000, 0xfff00000, "ARIN" },
	{ 0x81e40000, 0xfffc0000, "ARIN" },
	{ 0x81e90000, 0xffff0000, "ARIN" },
	{ 0x81ea0000, 0xfffe0000, "ARIN" },
	{ 0x81ec0000, 0xfffc0000, "ARIN" },
	{ 0x81f00000, 0xfff00000, "ARIN" },
	{ 0x82010000, 0xffff0000, "ARIN" },
	{ 0x820b0000, 0xffff0000, "ARIN" },
	{ 0x820c0000, 0xfffc0000, "ARIN" },
	{ 0x82100000, 0xfff80000, "ARIN" },
	{ 0x82180000, 0xfffc0000, "ARIN" },
	{ 0x821c0000, 0xfffe0000, "ARIN" },
	{ 0x821f0000, 0xffff0000, "ARIN" },
	{ 0x82200000, 0xfff80000, "ARIN" },
	{ 0x82280000, 0xfffe0000, "ARIN" },
	{ 0x822a0000, 0xffff0000, "ARIN" },
	{ 0x822c0000, 0xfffc0000, "ARIN" },
	{ 0x82300000, 0xfff00000, "ARIN" },
	{ 0x82400000, 0xffc00000, "ARIN" },
	{ 0x82800000, 0xfff80000, "ARIN" },
	{ 0x82880000, 0xfffc0000, "ARIN" },
	{ 0x82900000, 0xfffe0000, "ARIN" },
	{ 0x82940000, 0xfffc0000, "ARIN" },
	{ 0x82980000, 0xfff80000, "ARIN" },
	{ 0x82a00000, 0xfff00000, "ARIN" },
	{ 0x82b20000, 0xfffe0000, "ARIN" },
	{ 0x82b50000, 0xffff0000, "ARIN" },
	{ 0x82b60000, 0xfffe0000, "ARIN" },
	{ 0x82b80000, 0xfff80000, "ARIN" },
	{ 0x82c00000, 0xffff0000, "ARIN" },
	{ 0x82c20000, 0xfffe0000, "ARIN" },
	{ 0x82c40000, 0xfffc0000, "ARIN" },
	{ 0x82c80000, 0xfff80000, "ARIN" },
	{ 0x82d00000, 0xfff00000, "ARIN" },
	{ 0x82e00000, 0xfffe0000, "ARIN" },
	{ 0x82e20000, 0xffff0000, "ARIN" },
	{ 0x82e50000, 0xffff0000, "ARIN" },
	{ 0x82e60000, 0xfffe0000, "ARIN" },
	{ 0x82e80000, 0xfffc0000, "ARIN" },
	{ 0x82ec0000, 0xffff0000, "ARIN" },
	{ 0x82ee0000, 0xfffe0000, "ARIN" },
	{ 0x82f00000, 0xfffe0000, "ARIN" },
	{ 0x82f50000, 0xffff0000, "ARIN" },
	{ 0x82f60000, 0xfffe0000, "ARIN" },
	{ 0x82f80000, 0xfffc0000, "ARIN" },
	{ 0x82fc0000, 0xfffe0000, "ARIN" },
	{ 0x82fe0000, 0xffff0000, "ARIN" },
	{ 0x83010000, 0xffff0000, "ARIN" },
	{ 0x83020000, 0xfffe0000, "ARIN" },
	{ 0x83040000, 0xfffc0000, "ARIN" },
	{ 0x83080000, 0xfff80000, "ARIN" },
	{ 0x83100000, 0xfff00000, "ARIN" },
	{ 0x83200000, 0xffe00000, "ARIN" },
	{ 0x83400000, 0xfff00000, "ARIN" },
	{ 0x83500000, 0xfff80000, "ARIN" },
	{ 0x83580000, 0xfffe0000, "ARIN" },
	{ 0x835b0000, 0xffff0000, "ARIN" },
	{ 0x835c0000, 0xfffc0000, "ARIN" },
	{ 0x83600000, 0xfff80000, "ARIN" },
	{ 0x83680000, 0xfffc0000, "ARIN" },
	{ 0x836d0000, 0xffff0000, "ARIN" },
	{ 0x836e0000, 0xfffe0000, "ARIN" },
	{ 0x83700000, 0xfffc0000, "ARIN" },
	{ 0x83740000, 0xffff0000, "ARIN" },
	{ 0x83750000, 0xffff8000, "ARIN" },
	{ 0x83760000, 0xfffe0000, "ARIN" },
	{ 0x83780000, 0xfff80000, "ARIN" },
	{ 0x83800000, 0xfff80000, "ARIN" },
	{ 0x838e0000, 0xfffe0000, "ARIN" },
	{ 0x83900000, 0xfff00000, "ARIN" },
	{ 0x83a00000, 0xffe00000, "ARIN" },
	{ 0x83c00000, 0xfff00000, "ARIN" },
	{ 0x83d00000, 0xfff80000, "ARIN" },
	{ 0x83d80000, 0xfffc0000, "ARIN" },
	{ 0x83dc0000, 0xffff0000, "ARIN" },
	{ 0x83de0000, 0xfffe0000, "ARIN" },
	{ 0x83e00000, 0xfff00000, "ARIN" },
	{ 0x83f00000, 0xfff80000, "ARIN" },
	{ 0x83f80000, 0xfffc0000, "ARIN" },
	{ 0x83fc0000, 0xfffe0000, "ARIN" },
	{ 0x83fe0000, 0xffff0000, "ARIN" },
	{ 0x84010000, 0xffff0000, "ARIN" },
	{ 0x84020000, 0xfffe0000, "ARIN" },
	{ 0x84040000, 0xfffc0000, "ARIN" },
	{ 0x84080000, 0xfff80000, "ARIN" },
	{ 0x84100000, 0xfff00000, "ARIN" },
	{ 0x84200000, 0xffe00000, "ARIN" },
	{ 0x84400000, 0xfff00000, "ARIN" },
	{ 0x84500000, 0xfffc0000, "ARIN" },
	{ 0x84560000, 0xfffe0000, "ARIN" },
	{ 0x845e0000, 0xfffe0000, "ARIN" },
	{ 0x846d0000, 0xffff0000, "ARIN" },
	{ 0x846e0000, 0xfffe0000, "ARIN" },
	{ 0x84750000, 0xffff0000, "ARIN" },
	{ 0x84760000, 0xfffe0000, "ARIN" },
	{ 0x84850000, 0xffff0000, "ARIN" },
	{ 0x84860000, 0xfffe0000, "ARIN" },
	{ 0x84900000, 0xfff80000, "ARIN" },
	{ 0x84980000, 0xfffc0000, "ARIN" },
	{ 0x849c0000, 0xffff0000, "ARIN" },
	{ 0x849e0000, 0xfffe0000, "ARIN" },
	{ 0x84a00000, 0xfff00000, "ARIN" },
	{ 0x84b00000, 0xfff80000, "ARIN" },
	{ 0x84b90000, 0xffff0000, "ARIN" },
	{ 0x84ba0000, 0xfffe0000, "ARIN" },
	{ 0x84bc0000, 0xfffc0000, "ARIN" },
	{ 0x84c00000, 0xffe00000, "ARIN" },
	{ 0x84e00000, 0xfff00000, "ARIN" },
	{ 0x84f00000, 0xfff80000, "ARIN" },
	{ 0x84f80000, 0xfffc0000, "ARIN" },
	{ 0x84fc0000, 0xfffe0000, "ARIN" },
	{ 0x84fe0000, 0xffff0000, "ARIN" },
	{ 0x85000000, 0xff000000, "ARIN" },
	{ 0x86010000, 0xffff0000, "ARIN" },
	{ 0x86020000, 0xffff0000, "ARIN" },
	{ 0x86040000, 0xfffc0000, "ARIN" },
	{ 0x86080000, 0xfffc0000, "ARIN" },
	{ 0x860c0000, 0xfffe0000, "ARIN" },
	{ 0x86110000, 0xffff0000, "ARIN" },
	{ 0x86120000, 0xffff0000, "ARIN" },
	{ 0x86140000, 0xfffc0000, "ARIN" },
	{ 0x86180000, 0xfff80000, "ARIN" },
	{ 0x86200000, 0xfffc0000, "ARIN" },
	{ 0x86240000, 0xfffe0000, "ARIN" },
	{ 0x86270000, 0xffff0000, "ARIN" },
	{ 0x86280000, 0xfffc0000, "ARIN" },
	{ 0x862e0000, 0xfffe0000, "ARIN" },
	{ 0x86300000, 0xfff00000, "ARIN" },
	{ 0x86400000, 0xfff00000, "ARIN" },
	{ 0x86500000, 0xfff80000, "ARIN" },
	{ 0x86580000, 0xfffe0000, "ARIN" },
	{ 0x865b0000, 0xffff0000, "ARIN" },
	{ 0x865c0000, 0xfffc0000, "ARIN" },
	{ 0x86600000, 0xfffe0000, "ARIN" },
	{ 0x86630000, 0xffff0000, "ARIN" },
	{ 0x86640000, 0xfffc0000, "ARIN" },
	{ 0x86680000, 0xfff80000, "ARIN" },
	{ 0x86700000, 0xfff00000, "ARIN" },
	{ 0x86800000, 0xfff80000, "ARIN" },
	{ 0x86880000, 0xffff0000, "ARIN" },
	{ 0x868a0000, 0xfffe0000, "ARIN" },
	{ 0x868c0000, 0xfffc0000, "ARIN" },
	{ 0x86900000, 0xfff00000, "ARIN" },
	{ 0x86a00000, 0xffe00000, "ARIN" },
	{ 0x86c00000, 0xffe00000, "ARIN" },
	{ 0x86e00000, 0xfff00000, "ARIN" },
	{ 0x86f00000, 0xfff80000, "ARIN" },
	{ 0x86f80000, 0xffff0000, "ARIN" },
	{ 0x86fa0000, 0xfffe0000, "ARIN" },
	{ 0x86fc0000, 0xfffe0000, "ARIN" },
	{ 0x86fe0000, 0xffff0000, "ARIN" },
	{ 0x87010000, 0xffff0000, "ARIN" },
	{ 0x87080000, 0xfff80000, "ARIN" },
	{ 0x87100000, 0xfffe0000, "ARIN" },
	{ 0x87120000, 0xffff0000, "ARIN" },
	{ 0x87140000, 0xfffc0000, "ARIN" },
	{ 0x87180000, 0xfff80000, "ARIN" },
	{ 0x87230000, 0xffff0000, "ARIN" },
	{ 0x87240000, 0xfffc0000, "ARIN" },
	{ 0x87280000, 0xfff80000, "ARIN" },
	{ 0x87370000, 0xffff0000, "ARIN" },
	{ 0x87390000, 0xffff0000, "ARIN" },
	{ 0x873a0000, 0xfffe0000, "ARIN" },
	{ 0x873c0000, 0xfffc0000, "ARIN" },
	{ 0x87400000, 0xfffe0000, "ARIN" },
	{ 0x874a0000, 0xfffe0000, "ARIN" },
	{ 0x87540000, 0xfffc0000, "ARIN" },
	{ 0x87590000, 0xffff0000, "ARIN" },
	{ 0x875a0000, 0xfffe0000, "ARIN" },
	{ 0x875c0000, 0xfffc0000, "ARIN" },
	{ 0x87670000, 0xffff0000, "ARIN" },
	{ 0x87680000, 0xfff80000, "ARIN" },
	{ 0x87700000, 0xfffc0000, "ARIN" },
	{ 0x877a0000, 0xfffe0000, "ARIN" },
	{ 0x877e0000, 0xfffe0000, "ARIN" },
	{ 0x878a0000, 0xfffe0000, "ARIN" },
	{ 0x878c0000, 0xfffc0000, "ARIN" },
	{ 0x87940000, 0xfffc0000, "ARIN" },
	{ 0x879c0000, 0xfffc0000, "ARIN" },
	{ 0x87a00000, 0xfff80000, "ARIN" },
	{ 0x87a90000, 0xffff0000, "ARIN" },
	{ 0x87aa0000, 0xfffe0000, "ARIN" },
	{ 0x87ac0000, 0xfffc0000, "ARIN" },
	{ 0x87b40000, 0xfffc0000, "ARIN" },
	{ 0x87b80000, 0xfffc0000, "ARIN" },
	{ 0x87c40000, 0xfffe0000, "ARIN" },
	{ 0x87dc0000, 0xfffc0000, "ARIN" },
	{ 0x87f90000, 0xffff0000, "ARIN" },
	{ 0x87fa0000, 0xfffe0000, "ARIN" },
	{ 0x88010000, 0xffff0000, "ARIN" },
	{ 0x888d0000, 0xffff0000, "ARIN" },
	{ 0x888e0000, 0xfffe0000, "ARIN" },
	{ 0x88900000, 0xfff00000, "ARIN" },
	{ 0x88a00000, 0xfff80000, "ARIN" },
	{ 0x88a80000, 0xffff0000, "ARIN" },
	{ 0x88ab0000, 0xffff0000, "ARIN" },
	{ 0x88ac0000, 0xfffc0000, "ARIN" },
	{ 0x88b00000, 0xfff00000, "ARIN" },
	{ 0x88c60000, 0xfffe0000, "ARIN" },
	{ 0x88c80000, 0xfff80000, "ARIN" },
	{ 0x88d00000, 0xfff00000, "ARIN" },
	{ 0x88e00000, 0xfff80000, "ARIN" },
	{ 0x88e80000, 0xfffe0000, "ARIN" },
	{ 0x88eb0000, 0xffff0000, "ARIN" },
	{ 0x88ec0000, 0xfffc0000, "ARIN" },
	{ 0x88f00000, 0xfff80000, "ARIN" },
	{ 0x88f80000, 0xfffe0000, "ARIN" },
	{ 0x89010000, 0xffff0000, "ARIN" },
	{ 0x89020000, 0xfffe0000, "ARIN" },
	{ 0x89040000, 0xfffc0000, "ARIN" },
	{ 0x89080000, 0xfff80000, "ARIN" },
	{ 0x89100000, 0xfff80000, "ARIN" },
	{ 0x89180000, 0xfffe0000, "ARIN" },
	{ 0x891c0000, 0xfffc0000, "ARIN" },
	{ 0x89200000, 0xfff80000, "ARIN" },
	{ 0x89280000, 0xfffc0000, "ARIN" },
	{ 0x892c0000, 0xfffe0000, "ARIN" },
	{ 0x892e0000, 0xffff0000, "ARIN" },
	{ 0x89300000, 0xfff80000, "ARIN" },
	{ 0x89380000, 0xfffc0000, "ARIN" },
	{ 0x893c0000, 0xfffe0000, "ARIN" },
	{ 0x893e0000, 0xffff0000, "ARIN" },
	{ 0x89410000, 0xffff0000, "ARIN" },
	{ 0x89420000, 0xfffe0000, "ARIN" },
	{ 0x89440000, 0xfffc0000, "ARIN" },
	{ 0x89480000, 0xfff80000, "ARIN" },
	{ 0x89500000, 0xfff80000, "ARIN" },
	{ 0x895b0000, 0xffff0000, "ARIN" },
	{ 0x895c0000, 0xfffc0000, "ARIN" },
	{ 0x89600000, 0xffe00000, "ARIN" },
	{ 0x89800000, 0xfff80000, "ARIN" },
	{ 0x89880000, 0xfffe0000, "ARIN" },
	{ 0x898b0000, 0xffff0000, "ARIN" },
	{ 0x898c0000, 0xfffc0000, "ARIN" },
	{ 0x89900000, 0xfff00000, "ARIN" },
	{ 0x89a00000, 0xfff00000, "ARIN" },
	{ 0x89b00000, 0xfff80000, "ARIN" },
	{ 0x89ba0000, 0xfffe0000, "ARIN" },
	{ 0x89bc0000, 0xfffc0000, "ARIN" },
	{ 0x89c00000, 0xfffc0000, "ARIN" },
	{ 0x89c50000, 0xffff0000, "ARIN" },
	{ 0x89c60000, 0xfffe0000, "ARIN" },
	{ 0x89c80000, 0xfff80000, "ARIN" },
	{ 0x89d00000, 0xfff00000, "ARIN" },
	{ 0x89e00000, 0xfff00000, "ARIN" },
	{ 0x89f00000, 0xfff80000, "ARIN" },
	{ 0x89f80000, 0xfffc0000, "ARIN" },
	{ 0x89fc0000, 0xfffe0000, "ARIN" },
	{ 0x89fe0000, 0xffff0000, "ARIN" },
	{ 0x8a010000, 0xffff0000, "ARIN" },
	{ 0x8a020000, 0xfffe0000, "ARIN" },
	{ 0x8a040000, 0xfffc0000, "ARIN" },
	{ 0x8a080000, 0xfffc0000, "ARIN" },
	{ 0x8a0c0000, 0xfffe0000, "ARIN" },
	{ 0x8a0f0000, 0xffff0000, "ARIN" },
	{ 0x8a100000, 0xfff00000, "ARIN" },
	{ 0x8a200000, 0xfffc0000, "ARIN" },
	{ 0x8a250000, 0xffff0000, "ARIN" },
	{ 0x8a260000, 0xfffe0000, "ARIN" },
	{ 0x8a280000, 0xfff80000, "ARIN" },
	{ 0x8a300000, 0xfffc0000, "ARIN" },
	{ 0x8a340000, 0xfffe0000, "ARIN" },
	{ 0x8a3c0000, 0xfffc0000, "ARIN" },
	{ 0x8a400000, 0xfff00000, "ARIN" },
	{ 0x8a500000, 0xfff80000, "ARIN" },
	{ 0x8a580000, 0xfffc0000, "ARIN" },
	{ 0x8a5c0000, 0xfffe0000, "ARIN" },
	{ 0x8a5f0000, 0xffff0000, "ARIN" },
	{ 0x8a600000, 0xffff0000, "ARIN" },
	{ 0x8a620000, 0xffff0000, "ARIN" },
	{ 0x8a640000, 0xfffc0000, "ARIN" },
	{ 0x8a680000, 0xfff80000, "ARIN" },
	{ 0x8a700000, 0xfffc0000, "ARIN" },
	{ 0x8a740000, 0xffff0000, "ARIN" },
	{ 0x8a770000, 0xffff0000, "ARIN" },
	{ 0x8a780000, 0xfffe0000, "ARIN" },
	{ 0x8a7b0000, 0xffff0000, "ARIN" },
	{ 0x8a7c0000, 0xfffc0000, "ARIN" },
	{ 0x8a800000, 0xfff80000, "ARIN" },
	{ 0x8a880000, 0xfffe0000, "ARIN" },
	{ 0x8a8b0000, 0xffff0000, "ARIN" },
	{ 0x8a8c0000, 0xfffc0000, "ARIN" },
	{ 0x8a900000, 0xfff00000, "ARIN" },
	{ 0x8aa00000, 0xfff00000, "ARIN" },
	{ 0x8ab00000, 0xfff80000, "ARIN" },
	{ 0x8ab80000, 0xffff0000, "ARIN" },
	{ 0x8abb0000, 0xffff0000, "ARIN" },
	{ 0x8abc0000, 0xfffc0000, "ARIN" },
	{ 0x8ac00000, 0xfffc0000, "ARIN" },
	{ 0x8ac40000, 0xfffe0000, "ARIN" },
	{ 0x8ac70000, 0xffff0000, "ARIN" },
	{ 0x8ac80000, 0xfff80000, "ARIN" },
	{ 0x8ad00000, 0xfff80000, "ARIN" },
	{ 0x8ad80000, 0xfffe0000, "ARIN" },
	{ 0x8ada0000, 0xffff0000, "ARIN" },
	{ 0x8adc0000, 0xfffe0000, "ARIN" },
	{ 0x8ae50000, 0xffff0000, "ARIN" },
	{ 0x8ae60000, 0xfffe0000, "ARIN" },
	{ 0x8ae80000, 0xfff80000, "ARIN" },
	{ 0x8af00000, 0xfff80000, "ARIN" },
	{ 0x8af80000, 0xfffc0000, "ARIN" },
	{ 0x8afc0000, 0xfffe0000, "ARIN" },
	{ 0x8afe0000, 0xffff0000, "ARIN" },
	{ 0x8b010000, 0xffff0000, "ARIN" },
	{ 0x8b020000, 0xfffe0000, "ARIN" },
	{ 0x8b050000, 0xffff0000, "ARIN" },
	{ 0x8b060000, 0xfffe0000, "ARIN" },
	{ 0x8b080000, 0xffff0000, "ARIN" },
	{ 0x8b0a0000, 0xfffe0000, "ARIN" },
	{ 0x8b110000, 0xffff0000, "ARIN" },
	{ 0x8b120000, 0xfffe0000, "ARIN" },
	{ 0x8b1e0000, 0xfffe0000, "ARIN" },
	{ 0x8b200000, 0xffe00000, "ARIN" },
	{ 0x8b400000, 0xffe00000, "ARIN" },
	{ 0x8b600000, 0xfffc0000, "ARIN" },
	{ 0x8b640000, 0xffff0000, "ARIN" },
	{ 0x8b660000, 0xfffe0000, "ARIN" },
	{ 0x8b680000, 0xfff80000, "ARIN" },
	{ 0x8b700000, 0xfff00000, "ARIN" },
	{ 0x8b800000, 0xffff0000, "ARIN" },
	{ 0x8b820000, 0xfffe0000, "ARIN" },
	{ 0x8b840000, 0xfffc0000, "ARIN" },
	{ 0x8b880000, 0xfff80000, "ARIN" },
	{ 0x8b900000, 0xffff0000, "ARIN" },
	{ 0x8b920000, 0xfffe0000, "ARIN" },
	{ 0x8b950000, 0xffff0000, "ARIN" },
	{ 0x8b970000, 0xffff0000, "ARIN" },
	{ 0x8b980000, 0xfffe0000, "ARIN" },
	{ 0x8b9a0000, 0xffff0000, "ARIN" },
	{ 0x8b9e0000, 0xffff0000, "ARIN" },
	{ 0x8ba00000, 0xfff80000, "ARIN" },
	{ 0x8ba80000, 0xfffe0000, "ARIN" },
	{ 0x8bab0000, 0xffff0000, "ARIN" },
	{ 0x8bac0000, 0xfffc0000, "ARIN" },
	{ 0x8bb10000, 0xffff0000, "ARIN" },
	{ 0x8bb20000, 0xfffe0000, "ARIN" },
	{ 0x8bb40000, 0xfffe0000, "ARIN" },
	{ 0x8bb60000, 0xffff0000, "ARIN" },
	{ 0x8bb80000, 0xfffe0000, "ARIN" },
	{ 0x8bbb0000, 0xffff0000, "ARIN" },
	{ 0x8bbc0000, 0xffff0000, "ARIN" },
	{ 0x8bbf0000, 0xffff0000, "ARIN" },
	{ 0x8bde0000, 0xfffe0000, "ARIN" },
	{ 0x8be10000, 0xffff0000, "ARIN" },
	{ 0x8be50000, 0xffff0000, "ARIN" },
	{ 0x8be60000, 0xfffe0000, "ARIN" },
	{ 0x8be80000, 0xfff80000, "ARIN" },
	{ 0x8bf00000, 0xfff80000, "ARIN" },
	{ 0x8bf80000, 0xfffc0000, "ARIN" },
	{ 0x8bfc0000, 0xfffe0000, "ARIN" },
	{ 0x8bfe0000, 0xffff0000, "ARIN" },
	{ 0x8c010000, 0xffff0000, "ARIN" },
	{ 0x8c020000, 0xfffe0000, "ARIN" },
	{ 0x8c040000, 0xfffc0000, "ARIN" },
	{ 0x8c080000, 0xfff80000, "ARIN" },
	{ 0x8c100000, 0xfff00000, "ARIN" },
	{ 0x8c200000, 0xfff00000, "ARIN" },
	{ 0x8c310000, 0xffff0000, "ARIN" },
	{ 0x8c320000, 0xfffe0000, "ARIN" },
	{ 0x8c340000, 0xfffc0000, "ARIN" },
	{ 0x8c380000, 0xfff80000, "ARIN" },
	{ 0x8c400000, 0xfff80000, "ARIN" },
	{ 0x8c480000, 0xfffe0000, "ARIN" },
	{ 0x8c4a0000, 0xffff0000, "ARIN" },
	{ 0x8c4c0000, 0xfffc0000, "ARIN" },
	{ 0x8c500000, 0xfff00000, "ARIN" },
	{ 0x8c600000, 0xfff80000, "ARIN" },
	{ 0x8c680000, 0xfffc0000, "ARIN" },
	{ 0x8c6c0000, 0xfffe0000, "ARIN" },
	{ 0x8c700000, 0xfffc0000, "ARIN" },
	{ 0x8c740000, 0xfffe0000, "ARIN" },
	{ 0x8c8b0000, 0xffff0000, "ARIN" },
	{ 0x8c8c0000, 0xfffc0000, "ARIN" },
	{ 0x8c900000, 0xfffc0000, "ARIN" },
	{ 0x8c940000, 0xffff0000, "ARIN" },
	{ 0x8c960000, 0xfffe0000, "ARIN" },
	{ 0x8c980000, 0xfff80000, "ARIN" },
	{ 0x8ca00000, 0xffe00000, "ARIN" },
	{ 0x8cc00000, 0xfff80000, "ARIN" },
	{ 0x8cc80000, 0xfffc0000, "ARIN" },
	{ 0x8ccc0000, 0xffff0000, "ARIN" },
	{ 0x8cd00000, 0xfffe0000, "ARIN" },
	{ 0x8cd30000, 0xffff0000, "ARIN" },
	{ 0x8cd40000, 0xffff0000, "ARIN" },
	{ 0x8cd60000, 0xfffe0000, "ARIN" },
	{ 0x8cd80000, 0xfff80000, "ARIN" },
	{ 0x8ce10000, 0xffff0000, "ARIN" },
	{ 0x8ce20000, 0xfffe0000, "ARIN" },
	{ 0x8ce40000, 0xfffc0000, "ARIN" },
	{ 0x8ce80000, 0xfff80000, "ARIN" },
	{ 0x8cf00000, 0xfffc0000, "ARIN" },
	{ 0x8cf40000, 0xfffe0000, "ARIN" },
	{ 0x8cf70000, 0xffff0000, "ARIN" },
	{ 0x8cf80000, 0xfffe0000, "ARIN" },
	{ 0x8cfb0000, 0xffff0000, "ARIN" },
	{ 0x8cfc0000, 0xfffe0000, "ARIN" },
	{ 0x8cfe0000, 0xffff0000, "ARIN" },
	{ 0x8d560000, 0xfffe0000, "ARIN" },
	{ 0x8d580000, 0xfffc0000, "ARIN" },
	{ 0x8d5c0000, 0xfffe0000, "ARIN" },
	{ 0x8d630000, 0xffff0000, "ARIN" },
	{ 0x8d640000, 0xffff0000, "ARIN" },
	{ 0x8d660000, 0xfffe0000, "ARIN" },
	{ 0x8d680000, 0xffff0000, "ARIN" },
	{ 0x8d6a0000, 0xfffe0000, "ARIN" },
	{ 0x8d6c0000, 0xfffc0000, "ARIN" },
	{ 0x8d700000, 0xfff80000, "ARIN" },
	{ 0x8d780000, 0xfffc0000, "ARIN" },
	{ 0x8d7d0000, 0xffff0000, "ARIN" },
	{ 0x8d7e0000, 0xfffe0000, "ARIN" },
	{ 0x8d820000, 0xfffe0000, "ARIN" },
	{ 0x8d840000, 0xfffe0000, "ARIN" },
	{ 0x8d890000, 0xffff0000, "ARIN" },
	{ 0x8d8b0000, 0xffff0000, "ARIN" },
	{ 0x8d8c0000, 0xfffc0000, "ARIN" },
	{ 0x8d900000, 0xfffc0000, "ARIN" },
	{ 0x8d940000, 0xfffe0000, "ARIN" },
	{ 0x8d9f0000, 0xffff0000, "ARIN" },
	{ 0x8da00000, 0xfff80000, "ARIN" },
	{ 0x8da80000, 0xfffe0000, "ARIN" },
	{ 0x8dab0000, 0xffff0000, "ARIN" },
	{ 0x8dac0000, 0xfffc0000, "ARIN" },
	{ 0x8db00000, 0xfffc0000, "ARIN" },
	{ 0x8db70000, 0xffff0000, "ARIN" },
	{ 0x8db90000, 0xffff0000, "ARIN" },
	{ 0x8dbc0000, 0xfffc0000, "ARIN" },
	{ 0x8dc00000, 0xffe00000, "ARIN" },
	{ 0x8de00000, 0xfff80000, "ARIN" },
	{ 0x8de80000, 0xfffc0000, "ARIN" },
	{ 0x8dec0000, 0xffff0000, "ARIN" },
	{ 0x8dee0000, 0xfffe0000, "ARIN" },
	{ 0x8df00000, 0xfff80000, "ARIN" },
	{ 0x8df80000, 0xfffc0000, "ARIN" },
	{ 0x8dfc0000, 0xfffe0000, "ARIN" },
	{ 0x8dfe0000, 0xffff0000, "ARIN" },
	{ 0x8e010000, 0xffff0000, "ARIN" },
	{ 0x8e020000, 0xfffe0000, "ARIN" },
	{ 0x8e040000, 0xfffc0000, "ARIN" },
	{ 0x8e080000, 0xfffe0000, "ARIN" },
	{ 0x8e0a0000, 0xffff0000, "ARIN" },
	{ 0x8e0c0000, 0xfffc0000, "ARIN" },
	{ 0x8e100000, 0xfff00000, "ARIN" },
	{ 0x8e200000, 0xfff80000, "ARIN" },
	{ 0x8e280000, 0xfffc0000, "ARIN" },
	{ 0x8e2c0000, 0xfffe0000, "ARIN" },
	{ 0x8e330000, 0xffff0000, "ARIN" },
	{ 0x8e340000, 0xfffc0000, "ARIN" },
	{ 0x8e380000, 0xfff80000, "ARIN" },
	{ 0x8e400000, 0xfff00000, "ARIN" },
	{ 0x8e500000, 0xfffc0000, "ARIN" },
	{ 0x8e560000, 0xfffe0000, "ARIN" },
	{ 0x8e580000, 0xfffe0000, "ARIN" },
	{ 0x8e5a0000, 0xffff0000, "ARIN" },
	{ 0x8e5c0000, 0xfffc0000, "ARIN" },
	{ 0x8e600000, 0xfff80000, "ARIN" },
	{ 0x8e680000, 0xfffc0000, "ARIN" },
	{ 0x8e6c0000, 0xfffe0000, "ARIN" },
	{ 0x8e6e0000, 0xffff0000, "ARIN" },
	{ 0x8e700000, 0xfff00000, "ARIN" },
	{ 0x8e800000, 0xffff0000, "ARIN" },
	{ 0x8e820000, 0xfffe0000, "ARIN" },
	{ 0x8e840000, 0xfffc0000, "ARIN" },
	{ 0x8e880000, 0xfff80000, "ARIN" },
	{ 0x8e900000, 0xfff00000, "ARIN" },
	{ 0x8ea00000, 0xffe00000, "ARIN" },
	{ 0x8ec00000, 0xfffc0000, "ARIN" },
	{ 0x8ec60000, 0xfffe0000, "ARIN" },
	{ 0x8ec80000, 0xfff80000, "ARIN" },
	{ 0x8ed00000, 0xfff80000, "ARIN" },
	{ 0x8ed80000, 0xfffc0000, "ARIN" },
	{ 0x8edc0000, 0xfffe0000, "ARIN" },
	{ 0x8ede0000, 0xffff0000, "ARIN" },
	{ 0x8ee00000, 0xfff80000, "ARIN" },
	{ 0x8ee80000, 0xfffe0000, "ARIN" },
	{ 0x8eeb0000, 0xffff0000, "ARIN" },
	{ 0x8eec0000, 0xfffc0000, "ARIN" },
	{ 0x8ef00000, 0xfff80000, "ARIN" },
	{ 0x8ef80000, 0xfffe0000, "ARIN" },
	{ 0x8efa0000, 0xffff0000, "ARIN" },
	{ 0x8efd0000, 0xffff0000, "ARIN" },
	{ 0x8efe0000, 0xffff0000, "ARIN" },
	{ 0x8f010000, 0xffff0000, "ARIN" },
	{ 0x8f290000, 0xffff0000, "ARIN" },
	{ 0x8f2a0000, 0xfffe0000, "ARIN" },
	{ 0x8f2c0000, 0xfffc0000, "ARIN" },
	{ 0x8f300000, 0xfff00000, "ARIN" },
	{ 0x8f400000, 0xffc00000, "ARIN" },
	{ 0x8f800000, 0xfff80000, "ARIN" },
	{ 0x8f880000, 0xfffc0000, "ARIN" },
	{ 0x8f9e0000, 0xfffe0000, "ARIN" },
	{ 0x8fa00000, 0xffff0000, "ARIN" },
	{ 0x8fa20000, 0xfffe0000, "ARIN" },
	{ 0x8fa40000, 0xfffc0000, "ARIN" },
	{ 0x8fa80000, 0xfff80000, "ARIN" },
	{ 0x8fb00000, 0xfff00000, "ARIN" },
	{ 0x8fc00000, 0xfff80000, "ARIN" },
	{ 0x8fc80000, 0xfffe0000, "ARIN" },
	{ 0x8fcb0000, 0xffff0000, "ARIN" },
	{ 0x8fcc0000, 0xfffc0000, "ARIN" },
	{ 0x8fd10000, 0xffff0000, "ARIN" },
	{ 0x8fd20000, 0xfffe0000, "ARIN" },
	{ 0x8fd40000, 0xfffc0000, "ARIN" },
	{ 0x8fd80000, 0xfff80000, "ARIN" },
	{ 0x8fe00000, 0xfff00000, "ARIN" },
	{ 0x8ff00000, 0xfff80000, "ARIN" },
	{ 0x8ff80000, 0xfffc0000, "ARIN" },
	{ 0x8ffc0000, 0xfffe0000, "ARIN" },
	{ 0x8ffe0000, 0xffff0000, "ARIN" },
	{ 0x90010000, 0xffff0000, "ARIN" },
	{ 0x90020000, 0xfffe0000, "ARIN" },
	{ 0x90040000, 0xfffe0000, "ARIN" },
	{ 0x90060000, 0xffff0000, "ARIN" },
	{ 0x90080000, 0xfffc0000, "ARIN" },
	{ 0x900d0000, 0xffff0000, "ARIN" },
	{ 0x900e0000, 0xfffe0000, "ARIN" },
	{ 0x90100000, 0xfff00000, "ARIN" },
	{ 0x90200000, 0xfff00000, "ARIN" },
	{ 0x90300000, 0xfffc0000, "ARIN" },
	{ 0x90350000, 0xffff0000, "ARIN" },
	{ 0x90360000, 0xfffe0000, "ARIN" },
	{ 0x90380000, 0xfff80000, "ARIN" },
	{ 0x90410000, 0xffff0000, "ARIN" },
	{ 0x90420000, 0xfffe0000, "ARIN" },
	{ 0x90450000, 0xffff0000, "ARIN" },
	{ 0x90460000, 0xfffe0000, "ARIN" },
	{ 0x90480000, 0xfff80000, "ARIN" },
	{ 0x90500000, 0xfffc0000, "ARIN" },
	{ 0x90540000, 0xffff0000, "ARIN" },
	{ 0x90560000, 0xfffe0000, "ARIN" },
	{ 0x90580000, 0xfff80000, "ARIN" },
	{ 0x90600000, 0xfffe0000, "ARIN" },
	{ 0x90630000, 0xffff0000, "ARIN" },
	{ 0x90640000, 0xfffc0000, "ARIN" },
	{ 0x90680000, 0xfff80000, "ARIN" },
	{ 0x90700000, 0xfff80000, "ARIN" },
	{ 0x90780000, 0xfffe0000, "ARIN" },
	{ 0x907a0000, 0xffff0000, "ARIN" },
	{ 0x907c0000, 0xfffc0000, "ARIN" },
	{ 0x90800000, 0xffc00000, "ARIN" },
	{ 0x90c00000, 0xffe00000, "ARIN" },
	{ 0x90e00000, 0xfff00000, "ARIN" },
	{ 0x90f00000, 0xfff80000, "ARIN" },
	{ 0x90f80000, 0xfffc0000, "ARIN" },
	{ 0x90fc0000, 0xfffe0000, "ARIN" },
	{ 0x90fe0000, 0xffff0000, "ARIN" },
	{ 0x91800000, 0xffc00000, "ARIN" },
	{ 0x91c00000, 0xfff00000, "ARIN" },
	{ 0x91d00000, 0xfff80000, "ARIN" },
	{ 0x91d80000, 0xfffc0000, "ARIN" },
	{ 0x91dc0000, 0xfffe0000, "ARIN" },
	{ 0x91df0000, 0xffff0000, "ARIN" },
	{ 0x92010000, 0xffff0000, "ARIN" },
	{ 0x92020000, 0xfffe0000, "ARIN" },
	{ 0x92040000, 0xfffc0000, "ARIN" },
	{ 0x92080000, 0xfff80000, "ARIN" },
	{ 0x92100000, 0xfff80000, "ARIN" },
	{ 0x922f0000, 0xffff0000, "ARIN" },
	{ 0x92310000, 0xffff0000, "ARIN" },
	{ 0x92320000, 0xfffe0000, "ARIN" },
	{ 0x92350000, 0xffff0000, "ARIN" },
	{ 0x92360000, 0xfffe0000, "ARIN" },
	{ 0x92380000, 0xfffc0000, "ARIN" },
	{ 0x923d0000, 0xffff0000, "ARIN" },
	{ 0x923e0000, 0xfffe0000, "ARIN" },
	{ 0x92400000, 0xfffe0000, "ARIN" },
	{ 0x92430000, 0xffff0000, "ARIN" },
	{ 0x92440000, 0xfffc0000, "ARIN" },
	{ 0x92480000, 0xfff80000, "ARIN" },
	{ 0x92500000, 0xfff00000, "ARIN" },
	{ 0x92600000, 0xfff80000, "ARIN" },
	{ 0x92690000, 0xffff0000, "ARIN" },
	{ 0x926a0000, 0xfffe0000, "ARIN" },
	{ 0x926c0000, 0xfffc0000, "ARIN" },
	{ 0x92700000, 0xfff80000, "ARIN" },
	{ 0x92790000, 0xffff0000, "ARIN" },
	{ 0x927a0000, 0xfffe0000, "ARIN" },
	{ 0x927c0000, 0xfffc0000, "ARIN" },
	{ 0x92800000, 0xfff00000, "ARIN" },
	{ 0x92900000, 0xfff80000, "ARIN" },
	{ 0x92980000, 0xfffc0000, "ARIN" },
	{ 0x929c0000, 0xfffe0000, "ARIN" },
	{ 0x929f0000, 0xffff0000, "ARIN" },
	{ 0x92a00000, 0xfff00000, "ARIN" },
	{ 0x92b00000, 0xfff80000, "ARIN" },
	{ 0x92b80000, 0xffff0000, "ARIN" },
	{ 0x92ba0000, 0xfffe0000, "ARIN" },
	{ 0x92bd0000, 0xffff0000, "ARIN" },
	{ 0x92be0000, 0xfffe0000, "ARIN" },
	{ 0x92c00000, 0xfff00000, "ARIN" },
	{ 0x92d00000, 0xfffe0000, "ARIN" },
	{ 0x92df0000, 0xffff0000, "ARIN" },
	{ 0x92e00000, 0xfff00000, "ARIN" },
	{ 0x92f00000, 0xfffc0000, "ARIN" },
	{ 0x92f40000, 0xfffe0000, "ARIN" },
	{ 0x92f60000, 0xffff0000, "ARIN" },
	{ 0x92f80000, 0xfffe0000, "ARIN" },
	{ 0x92fa0000, 0xffff0000, "ARIN" },
	{ 0x92fc0000, 0xfffe0000, "ARIN" },
	{ 0x92fe0000, 0xffff0000, "ARIN" },
	{ 0x93010000, 0xffff0000, "ARIN" },
	{ 0x93020000, 0xfffe0000, "ARIN" },
	{ 0x93040000, 0xfffc0000, "ARIN" },
	{ 0x93080000, 0xfff80000, "ARIN" },
	{ 0x93100000, 0xfff80000, "ARIN" },
	{ 0x931a0000, 0xfffe0000, "ARIN" },
	{ 0x931c0000, 0xfffc0000, "ARIN" },
	{ 0x93200000, 0xffe00000, "ARIN" },
	{ 0x93400000, 0xffc00000, "ARIN" },
	{ 0x93800000, 0xffe00000, "ARIN" },
	{ 0x93a00000, 0xfffc0000, "ARIN" },
	{ 0x93a40000, 0xfffe0000, "ARIN" },
	{ 0x93a60000, 0xffff0000, "ARIN" },
	{ 0x93a80000, 0xfff80000, "ARIN" },
	{ 0x93b00000, 0xfff00000, "ARIN" },
	{ 0x93c00000, 0xfffe0000, "ARIN" },
	{ 0x93c30000, 0xffff0000, "ARIN" },
	{ 0x93c40000, 0xfffc0000, "ARIN" },
	{ 0x93c80000, 0xfff80000, "ARIN" },
	{ 0x93d00000, 0xfff00000, "ARIN" },
	{ 0x93e00000, 0xfff80000, "ARIN" },
	{ 0x93e80000, 0xffff0000, "ARIN" },
	{ 0x93ee0000, 0xfffe0000, "ARIN" },
	{ 0x93f00000, 0xfff80000, "ARIN" },
	{ 0x93f80000, 0xfffc0000, "ARIN" },
	{ 0x93fc0000, 0xfffe0000, "ARIN" },
	{ 0x93fe0000, 0xffff0000, "ARIN" },
	{ 0x94010000, 0xffff0000, "ARIN" },
	{ 0x94020000, 0xfffe0000, "ARIN" },
	{ 0x94040000, 0xfffc0000, "ARIN" },
	{ 0x94080000, 0xfffc0000, "ARIN" },
	{ 0x94330000, 0xffff0000, "ARIN" },
	{ 0x94340000, 0xfffc0000, "ARIN" },
	{ 0x94380000, 0xfff80000, "ARIN" },
	{ 0x944f0000, 0xffff0000, "ARIN" },
	{ 0x94500000, 0xffff0000, "ARIN" },
	{ 0x94520000, 0xfffe0000, "ARIN" },
	{ 0x94540000, 0xfffc0000, "ARIN" },
	{ 0x94580000, 0xfffc0000, "ARIN" },
	{ 0x945d0000, 0xffff0000, "ARIN" },
	{ 0x945e0000, 0xfffe0000, "ARIN" },
	{ 0x94600000, 0xfffc0000, "ARIN" },
	{ 0x94640000, 0xffff0000, "ARIN" },
	{ 0x94680000, 0xfff80000, "ARIN" },
	{ 0x94700000, 0xfff00000, "ARIN" },
	{ 0x94800000, 0xffc00000, "ARIN" },
	{ 0x94c00000, 0xfff80000, "ARIN" },
	{ 0x94c80000, 0xfffc0000, "ARIN" },
	{ 0x94fb0000, 0xffff0000, "ARIN" },
	{ 0x94fc0000, 0xfffe0000, "ARIN" },
	{ 0x94fe0000, 0xffff0000, "ARIN" },
	{ 0x95010000, 0xffff0000, "ARIN" },
	{ 0x95020000, 0xffff0000, "ARIN" },
	{ 0x95040000, 0xfffc0000, "ARIN" },
	{ 0x95080000, 0xfff80000, "ARIN" },
	{ 0x95100000, 0xfff80000, "ARIN" },
	{ 0x95180000, 0xfffe0000, "ARIN" },
	{ 0x951a0000, 0xffff0000, "ARIN" },
	{ 0x951c0000, 0xfffc0000, "ARIN" },
	{ 0x95200000, 0xffe00000, "ARIN" },
	{ 0x95400000, 0xffe00000, "ARIN" },
	{ 0x95600000, 0xfff00000, "ARIN" },
	{ 0x95700000, 0xfff80000, "ARIN" },
	{ 0x95780000, 0xfffc0000, "ARIN" },
	{ 0x957c0000, 0xfffe0000, "ARIN" },
	{ 0x957f0000, 0xffff0000, "ARIN" },
	{ 0x95800000, 0xfffc0000, "ARIN" },
	{ 0x95870000, 0xffff0000, "ARIN" },
	{ 0x95880000, 0xfffc0000, "ARIN" },
	{ 0x958d0000, 0xffff0000, "ARIN" },
	{ 0x958e0000, 0xfffe0000, "ARIN" },
	{ 0x95900000, 0xfff00000, "ARIN" },
	{ 0x95a00000, 0xffe00000, "ARIN" },
	{ 0x95c00000, 0xfff80000, "ARIN" },
	{ 0x95c90000, 0xffff0000, "ARIN" },
	{ 0x95cd0000, 0xffff0000, "ARIN" },
	{ 0x95fc0000, 0xfffe0000, "ARIN" },
	{ 0x95fe0000, 0xffff0000, "ARIN" },
	{ 0x96010000, 0xffff0000, "ARIN" },
	{ 0x96650000, 0xffff0000, "ARIN" },
	{ 0x96660000, 0xfffe0000, "ARIN" },
	{ 0x96680000, 0xfff80000, "ARIN" },
	{ 0x96700000, 0xfffe0000, "ARIN" },
	{ 0x96720000, 0xffff0000, "ARIN" },
	{ 0x96760000, 0xfffe0000, "ARIN" },
	{ 0x96780000, 0xffff0000, "ARIN" },
	{ 0x967b0000, 0xffff0000, "ARIN" },
	{ 0x967c0000, 0xfffc0000, "ARIN" },
	{ 0x96800000, 0xfff80000, "ARIN" },
	{ 0x96880000, 0xfffe0000, "ARIN" },
	{ 0x968d0000, 0xffff0000, "ARIN" },
	{ 0x968e0000, 0xfffe0000, "ARIN" },
	{ 0x96900000, 0xfff00000, "ARIN" },
	{ 0x96a00000, 0xfff80000, "ARIN" },
	{ 0x96a80000, 0xfffc0000, "ARIN" },
	{ 0x96ad0000, 0xffff0000, "ARIN" },
	{ 0x96ae0000, 0xfffe0000, "ARIN" },
	{ 0x96b00000, 0xfff00000, "ARIN" },
	{ 0x96c00000, 0xfff00000, "ARIN" },
	{ 0x96d00000, 0xfff80000, "ARIN" },
	{ 0x96d80000, 0xfffc0000, "ARIN" },
	{ 0x96dc0000, 0xfffe0000, "ARIN" },
	{ 0x96de0000, 0xffff0000, "ARIN" },
	{ 0x96e00000, 0xfff00000, "ARIN" },
	{ 0x96f10000, 0xffff0000, "ARIN" },
	{ 0x96f20000, 0xfffe0000, "ARIN" },
	{ 0x96f40000, 0xfffc0000, "ARIN" },
	{ 0x96f80000, 0xfffc0000, "ARIN" },
	{ 0x96fc0000, 0xfffe0000, "ARIN" },
	{ 0x97010000, 0xffff0000, "ARIN" },
	{ 0x97020000, 0xffff0000, "ARIN" },
	{ 0x97060000, 0xfffe0000, "ARIN" },
	{ 0x97080000, 0xfffe0000, "ARIN" },
	{ 0x970a0000, 0xffff0000, "ARIN" },
	{ 0x970c0000, 0xffff0000, "ARIN" },
	{ 0x97530000, 0xffff0000, "ARIN" },
	{ 0x97540000, 0xfffc0000, "ARIN" },
	{ 0x97580000, 0xfffe0000, "ARIN" },
	{ 0x975a0000, 0xffff0000, "ARIN" },
	{ 0x975e0000, 0xfffe0000, "ARIN" },
	{ 0x97600000, 0xfffe0000, "ARIN" },
	{ 0x97620000, 0xffff0000, "ARIN" },
	{ 0x97640000, 0xfffc0000, "ARIN" },
	{ 0x97680000, 0xfff80000, "ARIN" },
	{ 0x97700000, 0xfff00000, "ARIN" },
	{ 0x97800000, 0xffe00000, "ARIN" },
	{ 0x97a00000, 0xfff00000, "ARIN" },
	{ 0x97b00000, 0xfff80000, "ARIN" },
	{ 0x97b80000, 0xfffc0000, "ARIN" },
	{ 0x97bc0000, 0xffff0000, "ARIN" },
	{ 0x97be0000, 0xfffe0000, "ARIN" },
	{ 0x97c00000, 0xfff80000, "ARIN" },
	{ 0x97ce0000, 0xfffe0000, "ARIN" },
	{ 0x97d00000, 0xfff80000, "ARIN" },
	{ 0x98010000, 0xffff0000, "ARIN" },
	{ 0x98020000, 0xfffe0000, "ARIN" },
	{ 0x98040000, 0xfffc0000, "ARIN" },
	{ 0x98080000, 0xfff80000, "ARIN" },
	{ 0x98100000, 0xfff00000, "ARIN" },
	{ 0x98200000, 0xffe00000, "ARIN" },
	{ 0x98400000, 0xffe00000, "ARIN" },
	{ 0x98600000, 0xfff80000, "ARIN" },
	{ 0x98680000, 0xfffc0000, "ARIN" },
	{ 0x98710000, 0xffff0000, "ARIN" },
	{ 0x98720000, 0xfffe0000, "ARIN" },
	{ 0x98740000, 0xfffc0000, "ARIN" },
	{ 0x98780000, 0xfffe0000, "ARIN" },
	{ 0x987c0000, 0xfffc0000, "ARIN" },
	{ 0x98860000, 0xfffe0000, "ARIN" },
	{ 0x98880000, 0xfffc0000, "ARIN" },
	{ 0x988c0000, 0xfffe0000, "ARIN" },
	{ 0x988f0000, 0xffff0000, "ARIN" },
	{ 0x98900000, 0xfff00000, "ARIN" },
	{ 0x98a00000, 0xfffc0000, "ARIN" },
	{ 0x98a40000, 0xfffe0000, "ARIN" },
	{ 0x98b00000, 0xfff00000, "ARIN" },
	{ 0x98c00000, 0xfff80000, "ARIN" },
	{ 0x98d00000, 0xfff00000, "ARIN" },
	{ 0x98e20000, 0xfffe0000, "ARIN" },
	{ 0x98e40000, 0xfffe0000, "ARIN" },
	{ 0x99010000, 0xffff0000, "ARIN" },
	{ 0x99020000, 0xfffe0000, "ARIN" },
	{ 0x99040000, 0xfffc0000, "ARIN" },
	{ 0x99080000, 0xfff80000, "ARIN" },
	{ 0x99100000, 0xfff00000, "ARIN" },
	{ 0x99200000, 0xfffe0000, "ARIN" },
	{ 0x99260000, 0xfffe0000, "ARIN" },
	{ 0x99280000, 0xfffe0000, "ARIN" },
	{ 0x99320000, 0xfffe0000, "ARIN" },
	{ 0x99580000, 0xfffc0000, "ARIN" },
	{ 0x995c0000, 0xfffe0000, "ARIN" },
	{ 0x995e0000, 0xffff0000, "ARIN" },
	{ 0x99600000, 0xfffe0000, "ARIN" },
	{ 0x99620000, 0xffff0000, "ARIN" },
	{ 0x99640000, 0xffff0000, "ARIN" },
	{ 0x99660000, 0xfffe0000, "ARIN" },
	{ 0x99680000, 0xfff80000, "ARIN" },
	{ 0x99700000, 0xfffc0000, "ARIN" },
	{ 0x9a010000, 0xffff0000, "ARIN" },
	{ 0x9a020000, 0xfffe0000, "ARIN" },
	{ 0x9a040000, 0xfffc0000, "ARIN" },
	{ 0x9a080000, 0xfff80000, "ARIN" },
	{ 0x9a100000, 0xfff00000, "ARIN" },
	{ 0x9a200000, 0xffe00000, "ARIN" },
	{ 0x9a400000, 0xffff0000, "ARIN" },
	{ 0x9b010000, 0xffff0000, "ARIN" },
	{ 0x9b020000, 0xfffe0000, "ARIN" },
	{ 0x9b040000, 0xfffc0000, "ARIN" },
	{ 0x9b080000, 0xfffe0000, "ARIN" },
	{ 0x9b0a0000, 0xffff0000, "ARIN" },
	{ 0x9b0d0000, 0xffff0000, "ARIN" },
	{ 0x9b0e0000, 0xfffe0000, "ARIN" },
	{ 0x9b100000, 0xfff00000, "ARIN" },
	{ 0x9b200000, 0xffe00000, "ARIN" },
	{ 0x9b400000, 0xffe00000, "ARIN" },
	{ 0x9b600000, 0xfff00000, "ARIN" },
	{ 0x9b820000, 0xfffe0000, "ARIN" },
	{ 0x9b840000, 0xfffc0000, "ARIN" },
	{ 0x9b880000, 0xfff80000, "ARIN" },
	{ 0x9b900000, 0xfff00000, "ARIN" },
	{ 0x9ba00000, 0xffe00000, "ARIN" },
	{ 0x9bc00000, 0xfffc0000, "ARIN" },
	{ 0x9bc50000, 0xffff0000, "ARIN" },
	{ 0x9bc60000, 0xfffe0000, "ARIN" },
	{ 0x9bc80000, 0xfff80000, "ARIN" },
	{ 0x9bd00000, 0xfff00000, "ARIN" },
	{ 0x9be00000, 0xfff00000, "ARIN" },
	{ 0x9bf00000, 0xfff80000, "ARIN" },
	{ 0x9bf80000, 0xfffc0000, "ARIN" },
	{ 0x9bfc0000, 0xfffe0000, "ARIN" },
	{ 0x9bfe0000, 0xffff0000, "ARIN" },
	{ 0x9c010000, 0xffff0000, "ARIN" },
	{ 0x9c020000, 0xfffe0000, "ARIN" },
	{ 0x9c040000, 0xfffc0000, "ARIN" },
	{ 0x9c080000, 0xfff80000, "ARIN" },
	{ 0x9c100000, 0xfff00000, "ARIN" },
	{ 0x9c200000, 0xffe00000, "ARIN" },
	{ 0x9c400000, 0xffc00000, "ARIN" },
	{ 0x9c800000, 0xfff00000, "ARIN" },
	{ 0x9c900000, 0xfff80000, "ARIN" },
	{ 0x9c980000, 0xfffe0000, "ARIN" },
	{ 0x9d010000, 0xffff0000, "ARIN" },
	{ 0x9d020000, 0xfffe0000, "ARIN" },
	{ 0x9d040000, 0xfffc0000, "ARIN" },
	{ 0x9d080000, 0xfff80000, "ARIN" },
	{ 0x9d100000, 0xfff00000, "ARIN" },
	{ 0x9d360000, 0xfffe0000, "ARIN" },
	{ 0x9d3e0000, 0xfffe0000, "ARIN" },
	{ 0x9d400000, 0xffe00000, "ARIN" },
	{ 0x9d600000, 0xfff00000, "ARIN" },
	{ 0x9d700000, 0xfff80000, "ARIN" },
	{ 0x9d780000, 0xfffe0000, "ARIN" },
	{ 0x9d7b0000, 0xffff0000, "ARIN" },
	{ 0x9d7c0000, 0xffff0000, "ARIN" },
	{ 0x9d7e0000, 0xfffe0000, "ARIN" },
	{ 0x9d800000, 0xfff00000, "ARIN" },
	{ 0x9d900000, 0xfffc0000, "ARIN" },
	{ 0x9d950000, 0xffff0000, "ARIN" },
	{ 0x9d960000, 0xfffe0000, "ARIN" },
	{ 0x9d980000, 0xfff80000, "ARIN" },
	{ 0x9da00000, 0xfff00000, "ARIN" },
	{ 0x9db00000, 0xffff0000, "ARIN" },
	{ 0x9db20000, 0xfffe0000, "ARIN" },
	{ 0x9db40000, 0xfffc0000, "ARIN" },
	{ 0x9db80000, 0xfff80000, "ARIN" },
	{ 0x9dc00000, 0xffe00000, "ARIN" },
	{ 0x9de00000, 0xfff00000, "ARIN" },
	{ 0x9df00000, 0xfff80000, "ARIN" },
	{ 0x9df80000, 0xfffc0000, "ARIN" },
	{ 0x9dfc0000, 0xfffe0000, "ARIN" },
	{ 0x9dfe0000, 0xffff0000, "ARIN" },
	{ 0x9e010000, 0xffff0000, "ARIN" },
	{ 0x9e020000, 0xfffe0000, "ARIN" },
	{ 0x9e040000, 0xfffc0000, "ARIN" },
	{ 0x9e080000, 0xfff80000, "ARIN" },
	{ 0x9e100000, 0xfff00000, "ARIN" },
	{ 0x9e200000, 0xfff80000, "ARIN" },
	{ 0x9e280000, 0xfffc0000, "ARIN" },
	{ 0x9e2c0000, 0xfffe0000, "ARIN" },
	{ 0x9e2f0000, 0xffff0000, "ARIN" },
	{ 0x9e300000, 0xfff00000, "ARIN" },
	{ 0x9e400000, 0xffc00000, "ARIN" },
	{ 0x9e800000, 0xfff00000, "ARIN" },
	{ 0x9e900000, 0xfffc0000, "ARIN" },
	{ 0x9e950000, 0xffff0000, "ARIN" },
	{ 0x9e960000, 0xfffe0000, "ARIN" },
	{ 0x9e980000, 0xfff80000, "ARIN" },
	{ 0x9ea00000, 0xffe00000, "ARIN" },
	{ 0x9ec00000, 0xfff80000, "ARIN" },
	{ 0x9eda0000, 0xfffe0000, "ARIN" },
	{ 0x9edc0000, 0xfffc0000, "ARIN" },
	{ 0x9ee00000, 0xfff00000, "ARIN" },
	{ 0x9ef00000, 0xfff80000, "ARIN" },
	{ 0x9ef80000, 0xfffc0000, "ARIN" },
	{ 0x9efc0000, 0xfffe0000, "ARIN" },
	{ 0x9efe0000, 0xffff0000, "ARIN" },
	{ 0x9f010000, 0xffff0000, "ARIN" },
	{ 0x9f020000, 0xfffe0000, "ARIN" },
	{ 0x9f040000, 0xfffc0000, "ARIN" },
	{ 0x9f080000, 0xfff80000, "ARIN" },
	{ 0x9f100000, 0xfff00000, "ARIN" },
	{ 0x9f200000, 0xffe00000, "ARIN" },
	{ 0x9f400000, 0xfff00000, "ARIN" },
	{ 0x9f500000, 0xfffc0000, "ARIN" },
	{ 0x9f540000, 0xfffe0000, "ARIN" },
	{ 0x9f570000, 0xffff0000, "ARIN" },
	{ 0x9f580000, 0xfff80000, "ARIN" },
	{ 0x9f600000, 0xfffc0000, "ARIN" },
	{ 0x9f640000, 0xfffe0000, "ARIN" },
	{ 0x9f660000, 0xffff0000, "ARIN" },
	{ 0x9f690000, 0xffff0000, "ARIN" },
	{ 0x9f6a0000, 0xfffe0000, "ARIN" },
	{ 0x9f6c0000, 0xfffc0000, "ARIN" },
	{ 0x9f700000, 0xfff00000, "ARIN" },
	{ 0x9f800000, 0xfff00000, "ARIN" },
	{ 0x9f900000, 0xfffe0000, "ARIN" },
	{ 0x9f930000, 0xffff0000, "ARIN" },
	{ 0x9f940000, 0xfffc0000, "ARIN" },
	{ 0x9f980000, 0xfffc0000, "ARIN" },
	{ 0x9f9e0000, 0xfffe0000, "ARIN" },
	{ 0x9fa10000, 0xffff0000, "ARIN" },
	{ 0x9fa20000, 0xfffe0000, "ARIN" },
	{ 0x9fa40000, 0xfffc0000, "ARIN" },
	{ 0x9fa80000, 0xfff80000, "ARIN" },
	{ 0x9fb00000, 0xfff00000, "ARIN" },
	{ 0x9fc00000, 0xfff80000, "ARIN" },
	{ 0x9fc80000, 0xfffc0000, "ARIN" },
	{ 0x9fcc0000, 0xffff0000, "ARIN" },
	{ 0x9fce0000, 0xfffe0000, "ARIN" },
	{ 0x9fd00000, 0xfff00000, "ARIN" },
	{ 0x9fe10000, 0xffff0000, "ARIN" },
	{ 0x9fe20000, 0xfffe0000, "ARIN" },
	{ 0x9fe40000, 0xfffc0000, "ARIN" },
	{ 0x9fe80000, 0xfff80000, "ARIN" },
	{ 0x9ff00000, 0xfff80000, "ARIN" },
	{ 0x9ff80000, 0xfffc0000, "ARIN" },
	{ 0x9ffc0000, 0xffff0000, "ARIN" },
	{ 0x9ffe0000, 0xffff0000, "ARIN" },
	{ 0xa0010000, 0xffff0000, "ARIN" },
	{ 0xa0020000, 0xfffe0000, "ARIN" },
	{ 0xa0040000, 0xfffc0000, "ARIN" },
	{ 0xa0080000, 0xfff80000, "ARIN" },
	{ 0xa0100000, 0xfff00000, "ARIN" },
	{ 0xa0200000, 0xfff80000, "ARIN" },
	{ 0xa0280000, 0xfffc0000, "ARIN" },
	{ 0xa0400000, 0xfff00000, "ARIN" },
	{ 0xa0500000, 0xfff80000, "ARIN" },
	{ 0xa0580000, 0xffff0000, "ARIN" },
	{ 0xa05b0000, 0xffff0000, "ARIN" },
	{ 0xa05c0000, 0xfffc0000, "ARIN" },
	{ 0xa0600000, 0xfff80000, "ARIN" },
	{ 0xa0680000, 0xffff0000, "ARIN" },
	{ 0xa06a0000, 0xfffe0000, "ARIN" },
	{ 0xa06c0000, 0xfffc0000, "ARIN" },
	{ 0xa0700000, 0xffff0000, "ARIN" },
	{ 0xa0720000, 0xfffe0000, "ARIN" },
	{ 0xa0740000, 0xfffe0000, "ARIN" },
	{ 0xa0760000, 0xffff0000, "ARIN" },
	{ 0xa0790000, 0xffff0000, "ARIN" },
	{ 0xa07a0000, 0xfffe0000, "ARIN" },
	{ 0xa07c0000, 0xfffc0000, "ARIN" },
	{ 0xa0800000, 0xfff00000, "ARIN" },
	{ 0xa0900000, 0xfff80000, "ARIN" },
	{ 0xa0990000, 0xffff0000, "ARIN" },
	{ 0xa0b40000, 0xffff0000, "ARIN" },
	{ 0xa0b90000, 0xffff0000, "ARIN" },
	{ 0xa0ba0000, 0xfffe0000, "ARIN" },
	{ 0xa0bc0000, 0xfffc0000, "ARIN" },
	{ 0xa0c00000, 0xfff00000, "ARIN" },
	{ 0xa0d00000, 0xfffc0000, "ARIN" },
	{ 0xa0d40000, 0xffff0000, "ARIN" },
	{ 0xa0d60000, 0xfffe0000, "ARIN" },
	{ 0xa0dd0000, 0xffff0000, "ARIN" },
	{ 0xa0de0000, 0xfffe0000, "ARIN" },
	{ 0xa0e30000, 0xffff0000, "ARIN" },
	{ 0xa0e40000, 0xfffc0000, "ARIN" },
	{ 0xa0e80000, 0xfff80000, "ARIN" },
	{ 0xa0f00000, 0xfff80000, "ARIN" },
	{ 0xa0f80000, 0xfffc0000, "ARIN" },
	{ 0xa0fc0000, 0xfffe0000, "ARIN" },
	{ 0xa0fe0000, 0xffff0000, "ARIN" },
	{ 0xa1010000, 0xffff0000, "ARIN" },
	{ 0xa1020000, 0xfffe0000, "ARIN" },
	{ 0xa1040000, 0xfffc0000, "ARIN" },
	{ 0xa1080000, 0xfffe0000, "ARIN" },
	{ 0xa10b0000, 0xffff0000, "ARIN" },
	{ 0xa10c0000, 0xfffc0000, "ARIN" },
	{ 0xa1100000, 0xfffe0000, "ARIN" },
	{ 0xa1130000, 0xffff0000, "ARIN" },
	{ 0xa1140000, 0xfffc0000, "ARIN" },
	{ 0xa1180000, 0xfff80000, "ARIN" },
	{ 0xa1200000, 0xfff00000, "ARIN" },
	{ 0xa1300000, 0xfff80000, "ARIN" },
	{ 0xa1390000, 0xffff0000, "ARIN" },
	{ 0xa13a0000, 0xfffe0000, "ARIN" },
	{ 0xa13c0000, 0xfffc0000, "ARIN" },
	{ 0xa1400000, 0xffc00000, "ARIN" },
	{ 0xa1800000, 0xfff80000, "ARIN" },
	{ 0xa1880000, 0xfffe0000, "ARIN" },
	{ 0xa18b0000, 0xffff0000, "ARIN" },
	{ 0xa18d0000, 0xffff0000, "ARIN" },
	{ 0xa18e0000, 0xfffe0000, "ARIN" },
	{ 0xa1900000, 0xfff00000, "ARIN" },
	{ 0xa1a00000, 0xfffc0000, "ARIN" },
	{ 0xa1b20000, 0xfffe0000, "ARIN" },
	{ 0xa1b40000, 0xfffc0000, "ARIN" },
	{ 0xa1b80000, 0xfff80000, "ARIN" },
	{ 0xa1c00000, 0xffe00000, "ARIN" },
	{ 0xa1e00000, 0xfff80000, "ARIN" },
	{ 0xa1e80000, 0xfffe0000, "ARIN" },
	{ 0xa1eb0000, 0xffff0000, "ARIN" },
	{ 0xa1ec0000, 0xfffc0000, "ARIN" },
	{ 0xa1f00000, 0xfff80000, "ARIN" },
	{ 0xa1f80000, 0xfffc0000, "ARIN" },
	{ 0xa1fc0000, 0xfffe0000, "ARIN" },
	{ 0xa1fe0000, 0xffff0000, "ARIN" },
	{ 0xa2010000, 0xffff0000, "ARIN" },
	{ 0xa2020000, 0xfffe0000, "ARIN" },
	{ 0xa2040000, 0xfffc0000, "ARIN" },
	{ 0xa2080000, 0xfff80000, "ARIN" },
	{ 0xa2100000, 0xfff00000, "ARIN" },
	{ 0xa2200000, 0xffe00000, "ARIN" },
	{ 0xa2400000, 0xfff80000, "ARIN" },
	{ 0xa2490000, 0xffff0000, "ARIN" },
	{ 0xa24a0000, 0xfffe0000, "ARIN" },
	{ 0xa24c0000, 0xfffc0000, "ARIN" },
	{ 0xa2500000, 0xfffc0000, "ARIN" },
	{ 0xa2540000, 0xfffe0000, "ARIN" },
	{ 0xa2570000, 0xffff0000, "ARIN" },
	{ 0xa2580000, 0xfff80000, "ARIN" },
	{ 0xa2600000, 0xfff80000, "ARIN" },
	{ 0xa2690000, 0xffff0000, "ARIN" },
	{ 0xa26a0000, 0xfffe0000, "ARIN" },
	{ 0xa26c0000, 0xfffc0000, "ARIN" },
	{ 0xa2700000, 0xfff00000, "ARIN" },
	{ 0xa2800000, 0xfff00000, "ARIN" },
	{ 0xa2910000, 0xffff0000, "ARIN" },
	{ 0xa2920000, 0xfffe0000, "ARIN" },
	{ 0xa3010000, 0xffff0000, "ARIN" },
	{ 0xa3020000, 0xfffe0000, "ARIN" },
	{ 0xa3040000, 0xfffc0000, "ARIN" },
	{ 0xa3080000, 0xfffc0000, "ARIN" },
	{ 0xa30c0000, 0xfffe0000, "ARIN" },
	{ 0xa3210000, 0xffff0000, "ARIN" },
	{ 0xa3220000, 0xfffe0000, "ARIN" },
	{ 0xa3280000, 0xfff80000, "ARIN" },
	{ 0xa3300000, 0xfff00000, "ARIN" },
	{ 0xa3750000, 0xffff0000, "ARIN" },
	{ 0xa3760000, 0xfffe0000, "ARIN" },
	{ 0xa3780000, 0xfff80000, "ARIN" },
	{ 0xa3800000, 0xfffc0000, "ARIN" },
	{ 0xa3960000, 0xfffe0000, "ARIN" },
	{ 0xa3980000, 0xfffc0000, "ARIN" },
	{ 0xa3b00000, 0xffff0000, "ARIN" },
	{ 0xa3b20000, 0xfffe0000, "ARIN" },
	{ 0xa3b40000, 0xfffc0000, "ARIN" },
	{ 0xa3bd0000, 0xffff0000, "ARIN" },
	{ 0xa3be0000, 0xfffe0000, "ARIN" },
	{ 0xa3c00000, 0xfffe0000, "ARIN" },
	{ 0xa3c30000, 0xffff0000, "ARIN" },
	{ 0xa3c40000, 0xfffc0000, "ARIN" },
	{ 0xa3c80000, 0xfffc0000, "ARIN" },
	{ 0xa3cd0000, 0xffff0000, "ARIN" },
	{ 0xa3ce0000, 0xfffe0000, "ARIN" },
	{ 0xa3d00000, 0xfffc0000, "ARIN" },
	{ 0xa3d40000, 0xffff0000, "ARIN" },
	{ 0xa3d60000, 0xfffe0000, "ARIN" },
	{ 0xa3d80000, 0xfffc0000, "ARIN" },
	{ 0xa3dc0000, 0xfffe0000, "ARIN" },
	{ 0xa3df0000, 0xffff0000, "ARIN" },
	{ 0xa3e00000, 0xfffc0000, "ARIN" },
	{ 0xa3e40000, 0xffff0000, "ARIN" },
	{ 0xa3e60000, 0xfffe0000, "ARIN" },
	{ 0xa3e80000, 0xfffc0000, "ARIN" },
	{ 0xa3ed0000, 0xffff0000, "ARIN" },
	{ 0xa3ee0000, 0xfffe0000, "ARIN" },
	{ 0xa3f00000, 0xfff80000, "ARIN" },
	{ 0xa3f80000, 0xfffc0000, "ARIN" },
	{ 0xa3fc0000, 0xfffe0000, "ARIN" },
	{ 0xa3fe0000, 0xffff0000, "ARIN" },
	{ 0xa4290000, 0xffff0000, "ARIN" },
	{ 0xa42a0000, 0xfffe0000, "ARIN" },
	{ 0xa42c0000, 0xfffc0000, "ARIN" },
	{ 0xa4300000, 0xfff80000, "ARIN" },
	{ 0xa4380000, 0xfffc0000, "ARIN" },
	{ 0xa43d0000, 0xffff0000, "ARIN" },
	{ 0xa43e0000, 0xfffe0000, "ARIN" },
	{ 0xa4400000, 0xfffc0000, "ARIN" },
	{ 0xa4440000, 0xfffe0000, "ARIN" },
	{ 0xa4480000, 0xfff80000, "ARIN" },
	{ 0xa4500000, 0xfff00000, "ARIN" },
	{ 0xa4600000, 0xfff00000, "ARIN" },
	{ 0xa4700000, 0xfff80000, "ARIN" },
	{ 0xa4780000, 0xfffc0000, "ARIN" },
	{ 0xa47c0000, 0xfffe0000, "ARIN" },
	{ 0xa4900000, 0xfffc0000, "ARIN" },
	{ 0xa4980000, 0xfff80000, "ARIN" },
	{ 0xa4a00000, 0xfff80000, "ARIN" },
	{ 0xa4a80000, 0xffff0000, "ARIN" },
	{ 0xa4ab0000, 0xffff0000, "ARIN" },
	{ 0xa4b20000, 0xfffe0000, "ARIN" },
	{ 0xa4b40000, 0xfffc0000, "ARIN" },
	{ 0xa4be0000, 0xfffe0000, "ARIN" },
	{ 0xa4c30000, 0xffff0000, "ARIN" },
	{ 0xa4c40000, 0xfffc0000, "ARIN" },
	{ 0xa4c80000, 0xfffc0000, "ARIN" },
	{ 0xa4cf0000, 0xffff0000, "ARIN" },
	{ 0xa4d50000, 0xffff0000, "ARIN" },
	{ 0xa4d60000, 0xffff0000, "ARIN" },
	{ 0xa4d80000, 0xfffc0000, "ARIN" },
	{ 0xa4dc0000, 0xfffe0000, "ARIN" },
	{ 0xa4df0000, 0xffff0000, "ARIN" },
	{ 0xa4e00000, 0xfff80000, "ARIN" },
	{ 0xa4e80000, 0xffff0000, "ARIN" },
	{ 0xa4eb0000, 0xffff0000, "ARIN" },
	{ 0xa5010000, 0xffff0000, "ARIN" },
	{ 0xa5020000, 0xfffe0000, "ARIN" },
	{ 0xa5060000, 0xfffe0000, "ARIN" },
	{ 0xa5080000, 0xfff80000, "ARIN" },
	{ 0xa5100000, 0xfff00000, "ARIN" },
	{ 0xa5200000, 0xfff00000, "ARIN" },
	{ 0xa5400000, 0xfff00000, "ARIN" },
	{ 0xa5500000, 0xfff80000, "ARIN" },
	{ 0xa5580000, 0xfffe0000, "ARIN" },
	{ 0xa55b0000, 0xffff0000, "ARIN" },
	{ 0xa55c0000, 0xfffc0000, "ARIN" },
	{ 0xa5600000, 0xffe00000, "ARIN" },
	{ 0xa5800000, 0xfff00000, "ARIN" },
	{ 0xa5960000, 0xfffe0000, "ARIN" },
	{ 0xa5980000, 0xfff80000, "ARIN" },
	{ 0xa5a00000, 0xfff80000, "ARIN" },
	{ 0xa5a80000, 0xffff0000, "ARIN" },
	{ 0xa5aa0000, 0xfffe0000, "ARIN" },
	{ 0xa5ac0000, 0xfffc0000, "ARIN" },
	{ 0xa5b00000, 0xfff00000, "ARIN" },
	{ 0xa5c00000, 0xfffc0000, "ARIN" },
	{ 0xa5c40000, 0xfffe0000, "ARIN" },
	{ 0xa5c70000, 0xffff0000, "ARIN" },
	{ 0xa5c80000, 0xfff80000, "ARIN" },
	{ 0xa5d00000, 0xfffe0000, "ARIN" },
	{ 0xa5d40000, 0xffff8000, "ARIN" },
	{ 0xa5d50000, 0xffff0000, "ARIN" },
	{ 0xa5d60000, 0xfffe0000, "ARIN" },
	{ 0xa5d80000, 0xfff80000, "ARIN" },
	{ 0xa5e00000, 0xfff00000, "ARIN" },
	{ 0xa5f00000, 0xfffc0000, "ARIN" },
	{ 0xa5f50000, 0xffff0000, "ARIN" },
	{ 0xa5f60000, 0xfffe0000, "ARIN" },
	{ 0xa5f80000, 0xfffc0000, "ARIN" },
	{ 0xa5fc0000, 0xfffe0000, "ARIN" },
	{ 0xa5fe0000, 0xffff0000, "ARIN" },
	{ 0xa6020000, 0xfffe0000, "ARIN" },
	{ 0xa6080000, 0xfff80000, "ARIN" },
	{ 0xa6100000, 0xffff8000, "ARIN" },
	{ 0xa6110000, 0xffff0000, "ARIN" },
	{ 0xa6130000, 0xffff0000, "ARIN" },
	{ 0xa6140000, 0xfffe0000, "ARIN" },
	{ 0xa6200000, 0xffe00000, "ARIN" },
	{ 0xa6400000, 0xffc00000, "ARIN" },
	{ 0xa6800000, 0xff800000, "ARIN" },
	{ 0xa7010000, 0xffff0000, "ARIN" },
	{ 0xa7020000, 0xfffe0000, "ARIN" },
	{ 0xa7040000, 0xfffc0000, "ARIN" },
	{ 0xa7080000, 0xfff80000, "ARIN" },
	{ 0xa7100000, 0xfff00000, "ARIN" },
	{ 0xa7200000, 0xfff00000, "ARIN" },
	{ 0xa7300000, 0xfff80000, "ARIN" },
	{ 0xa7400000, 0xfff80000, "ARIN" },
	{ 0xa7480000, 0xfffe0000, "ARIN" },
	{ 0xa74a0000, 0xffffc000, "ARIN" },
	{ 0xa74a4000, 0xffffe000, "ARIN" },
	{ 0xa74b0000, 0xffff0000, "ARIN" },
	{ 0xa74c0000, 0xfffc0000, "ARIN" },
	{ 0xa7500000, 0xfff00000, "ARIN" },
	{ 0xa7600000, 0xfff80000, "ARIN" },
	{ 0xa7680000, 0xfffc0000, "ARIN" },
	{ 0xa76d0000, 0xffff0000, "ARIN" },
	{ 0xa76e0000, 0xfffe0000, "ARIN" },
	{ 0xa7700000, 0xfff00000, "ARIN" },
	{ 0xa7800000, 0xffc00000, "ARIN" },
	{ 0xa7c00000, 0xfff80000, "ARIN" },
	{ 0xa7c90000, 0xffff0000, "ARIN" },
	{ 0xa7ca0000, 0xfffe0000, "ARIN" },
	{ 0xa7cc0000, 0xfffc0000, "ARIN" },
	{ 0xa7d00000, 0xfff00000, "ARIN" },
	{ 0xa7e00000, 0xfff00000, "ARIN" },
	{ 0xa7f00000, 0xfff80000, "ARIN" },
	{ 0xa7f80000, 0xffff0000, "ARIN" },
	{ 0xa7fa0000, 0xfffe0000, "ARIN" },
	{ 0xa7fc0000, 0xfffc0000, "ARIN" },
	{ 0xa8010000, 0xffff0000, "ARIN" },
	{ 0xa8020000, 0xfffe0000, "ARIN" },
	{ 0xa8080000, 0xfff80000, "ARIN" },
	{ 0xa8100000, 0xfff00000, "ARIN" },
	{ 0xa8200000, 0xfff00000, "ARIN" },
	{ 0xa83d0000, 0xffff0000, "ARIN" },
	{ 0xa8400000, 0xfff00000, "ARIN" },
	{ 0xa8500000, 0xfff80000, "ARIN" },
	{ 0xa8580000, 0xfffe0000, "ARIN" },
	{ 0xa85b0000, 0xffff0000, "ARIN" },
	{ 0xa85c0000, 0xfffc0000, "ARIN" },
	{ 0xa8600000, 0xfff00000, "ARIN" },
	{ 0xa8700000, 0xfff80000, "ARIN" },
	{ 0xa8780000, 0xffff0000, "ARIN" },
	{ 0xa87a0000, 0xfffe0000, "ARIN" },
	{ 0xa87c0000, 0xfffc0000, "ARIN" },
	{ 0xa8800000, 0xffe00000, "ARIN" },
	{ 0xa8a00000, 0xfff00000, "ARIN" },
	{ 0xa8b00000, 0xfffe0000, "ARIN" },
	{ 0xa8b60000, 0xfffe0000, "ARIN" },
	{ 0xa8b80000, 0xfff80000, "ARIN" },
	{ 0xa8c60000, 0xfffe0000, "ARIN" },
	{ 0xa8c80000, 0xfff80000, "ARIN" },
	{ 0xa8d00000, 0xfffe0000, "ARIN" },
	{ 0xa8d40000, 0xfffc0000, "ARIN" },
	{ 0xa8d80000, 0xfff80000, "ARIN" },
	{ 0xa8e00000, 0xfffe0000, "ARIN" },
	{ 0xa8e20000, 0xffff0000, "ARIN" },
	{ 0xa8e50000, 0xffff0000, "ARIN" },
	{ 0xa8e60000, 0xfffe0000, "ARIN" },
	{ 0xa8e90000, 0xffff0000, "ARIN" },
	{ 0xa8ea0000, 0xfffe0000, "ARIN" },
	{ 0xa8ec0000, 0xfffc0000, "ARIN" },
	{ 0xa8f00000, 0xfff00000, "ARIN" },
	{ 0xa9020000, 0xfffe0000, "ARIN" },
	{ 0xa9040000, 0xfffc0000, "ARIN" },
	{ 0xa9080000, 0xfff80000, "ARIN" },
	{ 0xa9100000, 0xfff00000, "ARIN" },
	{ 0xa9200000, 0xffe00000, "ARIN" },
	{ 0xa9400000, 0xffc00000, "ARIN" },
	{ 0xa9800000, 0xfff00000, "ARIN" },
	{ 0xa9900000, 0xfff80000, "ARIN" },
	{ 0xa9980000, 0xfffc0000, "ARIN" },
	{ 0xa99c0000, 0xfffe0000, "ARIN" },
	{ 0xa99e0000, 0xffff0000, "ARIN" },
	{ 0xa9a00000, 0xfff00000, "ARIN" },
	{ 0xa9b80000, 0xfffe0000, "ARIN" },
	{ 0xa9c40000, 0xffff0000, "ARIN" },
	{ 0xa9c50000, 0xffffc000, "ARIN" },
	{ 0xa9c60000, 0xfffe0000, "ARIN" },
	{ 0xa9c80000, 0xfff80000, "ARIN" },
	{ 0xa9e00000, 0xfff80000, "ARIN" },
	{ 0xa9ee0000, 0xffff0000, "ARIN" },
	{ 0xa9f00000, 0xfffc0000, "ARIN" },
	{ 0xa9f40000, 0xfffe0000, "ARIN" },
	{ 0xa9fc0000, 0xfffe0000, "ARIN" },
	{ 0xaa010000, 0xffff0000, "ARIN" },
	{ 0xaa020000, 0xfffe0000, "ARIN" },
	{ 0xaa040000, 0xfffc0000, "ARIN" },
	{ 0xaa080000, 0xfff80000, "ARIN" },
	{ 0xaa100000, 0xfff00000, "ARIN" },
	{ 0xaa200000, 0xfff80000, "ARIN" },
	{ 0xaa280000, 0xfffc0000, "ARIN" },
	{ 0xaa2e0000, 0xfffe0000, "ARIN" },
	{ 0xaa300000, 0xfff80000, "ARIN" },
	{ 0xaa380000, 0xfffc0000, "ARIN" },
	{ 0xaa3d0000, 0xffff0000, "ARIN" },
	{ 0xaa3e0000, 0xfffe0000, "ARIN" },
	{ 0xaa400000, 0xfff80000, "ARIN" },
	{ 0xaa480000, 0xfffc0000, "ARIN" },
	{ 0xaa4c0000, 0xfffe0000, "ARIN" },
	{ 0xaa550000, 0xffff0000, "ARIN" },
	{ 0xaa560000, 0xfffe0000, "ARIN" },
	{ 0xaa580000, 0xfff80000, "ARIN" },
	{ 0xaa600000, 0xffe00000, "ARIN" },
	{ 0xaa800000, 0xfff80000, "ARIN" },
	{ 0xaa880000, 0xfffc0000, "ARIN" },
	{ 0xaa8c0000, 0xfffe0000, "ARIN" },
	{ 0xaa900000, 0xfffc0000, "ARIN" },
	{ 0xaa940000, 0xfffe0000, "ARIN" },
	{ 0xaa970000, 0xffff0000, "ARIN" },
	{ 0xaa980000, 0xfff80000, "ARIN" },
	{ 0xaaa00000, 0xffe00000, "ARIN" },
	{ 0xaac00000, 0xffe00000, "ARIN" },
	{ 0xaae00000, 0xfff80000, "ARIN" },
	{ 0xaae80000, 0xffff0000, "ARIN" },
	{ 0xaaea0000, 0xfffe0000, "ARIN" },
	{ 0xaaf00000, 0xfffc0000, "ARIN" },
	{ 0xaaf80000, 0xfffe0000, "ARIN" },
	{ 0xaafb0000, 0xffff0000, "ARIN" },
	{ 0xaafd0000, 0xffff0000, "ARIN" },
	{ 0xaaff0000, 0xffff0000, "ARIN" },
	{ 0xab400000, 0xfff80000, "ARIN" },
	{ 0xab480000, 0xfffe0000, "ARIN" },
	{ 0xab800000, 0xffc00000, "ARIN" },
	{ 0xac800000, 0xffc00000, "ARIN" },
	{ 0xacc00000, 0xfffc0000, "ARIN" },
	{ 0xbfff0000, 0xffff0000, "ARIN" },
	{ 0xc0000000, 0xfffc0000, "ARIN" },
	{ 0xc0040000, 0xfffe0000, "ARIN" },
	{ 0xc0060000, 0xffffe000, "ARIN" },
	{ 0xc0068000, 0xffffe000, "ARIN" },
	{ 0xc0070000, 0xffff0000, "ARIN" },
	{ 0xc0080000, 0xffff0000, "ARIN" },
	{ 0xc0090000, 0xffffe000, "ARIN" },
	{ 0xc009c000, 0xffffe000, "ARIN" },
	{ 0xc00a0000, 0xfffe0000, "ARIN" },
	{ 0xc00c0000, 0xfffe0000, "ARIN" },
	{ 0xc00f0000, 0xffff0000, "ARIN" },
	{ 0xc0100000, 0xffffe000, "ARIN" },
	{ 0xc0104000, 0xffffc000, "ARIN" },
	{ 0xc0108000, 0xffff8000, "ARIN" },
	{ 0xc0110000, 0xffff0000, "ARIN" },
	{ 0xc0120000, 0xffff8000, "ARIN" },
	{ 0xc012c000, 0xffffe000, "ARIN" },
	{ 0xc0130000, 0xffff0000, "ARIN" },
	{ 0xc0140000, 0xffff8000, "ARIN" },
	{ 0xc014e000, 0xffffe000, "ARIN" },
	{ 0xc0150000, 0xffff0000, "ARIN" },
	{ 0xc0160000, 0xfffe0000, "ARIN" },
	{ 0xc0180000, 0xfffc0000, "ARIN" },
	{ 0xc01c0000, 0xffffc000, "ARIN" },
	{ 0xc01c6000, 0xffffe000, "ARIN" },
	{ 0xc01c8000, 0xffffe000, "ARIN" },
	{ 0xc01d0000, 0xffff0000, "ARIN" },
	{ 0xc01e0000, 0xfffe0000, "ARIN" },
	{ 0xc0200000, 0xfffc0000, "ARIN" },
	{ 0xc0250000, 0xffff0000, "ARIN" },
	{ 0xc0270000, 0xffffe000, "ARIN" },
	{ 0xc0280000, 0xffff0000, "ARIN" },
	{ 0xc0290000, 0xffffc000, "ARIN" },
	{ 0xc0296000, 0xffffe000, "ARIN" },
	{ 0xc0298000, 0xffff8000, "ARIN" },
	{ 0xc02a0000, 0xffff0000, "ARIN" },
	{ 0xc02b0000, 0xffffe000, "ARIN" },
	{ 0xc02b8000, 0xffff8000, "ARIN" },
	{ 0xc02c0000, 0xffffc000, "ARIN" },
	{ 0xc02c4000, 0xffffe000, "ARIN" },
	{ 0xc02cc000, 0xffffc000, "ARIN" },
	{ 0xc02d0000, 0xffff0000, "ARIN" },
	{ 0xc02e0000, 0xffff0000, "ARIN" },
	{ 0xc02f0000, 0xffff8000, "ARIN" },
	{ 0xc02fe000, 0xffffe000, "ARIN" },
	{ 0xc0300000, 0xffff8000, "ARIN" },
	{ 0xc0308000, 0xffffe000, "ARIN" },
	{ 0xc030c000, 0xffffc000, "ARIN" },
	{ 0xc0310000, 0xffffe000, "ARIN" },
	{ 0xc0314000, 0xffffe000, "ARIN" },
	{ 0xc0320000, 0xffff0000, "ARIN" },
	{ 0xc0330000, 0xffffe000, "ARIN" },
	{ 0xc0340000, 0xffff0000, "ARIN" },
	{ 0xc0350000, 0xffffc000, "ARIN" },
	{ 0xc0356000, 0xffffe000, "ARIN" },
	{ 0xc0360000, 0xfffe0000, "ARIN" },
	{ 0xc0380000, 0xfffe0000, "ARIN" },
	{ 0xc03a0000, 0xffffc000, "ARIN" },
	{ 0xc03a6000, 0xffffe000, "ARIN" },
	{ 0xc03a8000, 0xffff8000, "ARIN" },
	{ 0xc03b0000, 0xffff0000, "ARIN" },
	{ 0xc0400000, 0xfffc0000, "ARIN" },
	{ 0xc0440000, 0xfffe0000, "ARIN" },
	{ 0xc0460000, 0xffffc000, "ARIN" },
	{ 0xc0466000, 0xffffe000, "ARIN" },
	{ 0xc0468000, 0xffff8000, "ARIN" },
	{ 0xc0480000, 0xffffe000, "ARIN" },
	{ 0xc048e000, 0xffffe000, "ARIN" },
	{ 0xc0490000, 0xffffc000, "ARIN" },
	{ 0xc0494000, 0xffffe000, "ARIN" },
	{ 0xc049c000, 0xffffc000, "ARIN" },
	{ 0xc04a0000, 0xffff8000, "ARIN" },
	{ 0xc04a8000, 0xffffe000, "ARIN" },
	{ 0xc04ac000, 0xffffe000, "ARIN" },
	{ 0xc04b0000, 0xffff0000, "ARIN" },
	{ 0xc04c0000, 0xffffc000, "ARIN" },
	{ 0xc04c6000, 0xffffe000, "ARIN" },
	{ 0xc04c8000, 0xffff8000, "ARIN" },
	{ 0xc04d0000, 0xffff0000, "ARIN" },
	{ 0xc04e0000, 0xffffe000, "ARIN" },
	{ 0xc04ea000, 0xffffe000, "ARIN" },
	{ 0xc04f0000, 0xffff0000, "ARIN" },
	{ 0xc0500000, 0xffffc000, "ARIN" },
	{ 0xc0504000, 0xffffe000, "ARIN" },
	{ 0xc050c000, 0xffffe000, "ARIN" },
	{ 0xc0510000, 0xffff0000, "ARIN" },
	{ 0xc0520000, 0xffffc000, "ARIN" },
	{ 0xc0526000, 0xffffe000, "ARIN" },
	{ 0xc0528000, 0xffff8000, "ARIN" },
	{ 0xc0530000, 0xffff0000, "ARIN" },
	{ 0xc0540000, 0xfffe0000, "ARIN" },
	{ 0xc0560000, 0xffffe000, "ARIN" },
	{ 0xc0564000, 0xffffc000, "ARIN" },
	{ 0xc0568000, 0xffff8000, "ARIN" },
	{ 0xc0570000, 0xffff0000, "ARIN" },
	{ 0xc0580000, 0xfffc0000, "ARIN" },
	{ 0xc05c0000, 0xffffe000, "ARIN" },
	{ 0xc05c4000, 0xffffc000, "ARIN" },
	{ 0xc05c8000, 0xffffc000, "ARIN" },
	{ 0xc05cc000, 0xffffe000, "ARIN" },
	{ 0xc05d0000, 0xffff0000, "ARIN" },
	{ 0xc05e0000, 0xffff0000, "ARIN" },
	{ 0xc05f4000, 0xffffe000, "ARIN" },
	{ 0xc0600000, 0xfffe0000, "ARIN" },
	{ 0xc0620000, 0xffff0000, "ARIN" },
	{ 0xc0640000, 0xffff8000, "ARIN" },
	{ 0xc0648000, 0xffffe000, "ARIN" },
	{ 0xc0650000, 0xffff0000, "ARIN" },
	{ 0xc0660000, 0xffffe000, "ARIN" },
	{ 0xc0664000, 0xffffc000, "ARIN" },
	{ 0xc0668000, 0xffff8000, "ARIN" },
	{ 0xc0670000, 0xffff8000, "ARIN" },
	{ 0xc0678000, 0xffffe000, "ARIN" },
	{ 0xc067e000, 0xffffe000, "ARIN" },
	{ 0xc0680000, 0xffff8000, "ARIN" },
	{ 0xc0688000, 0xffffc000, "ARIN" },
	{ 0xc068e000, 0xffffe000, "ARIN" },
	{ 0xc0690000, 0xffffc000, "ARIN" },
	{ 0xc069c000, 0xffffe000, "ARIN" },
	{ 0xc06a0000, 0xfffe0000, "ARIN" },
	{ 0xc06c0000, 0xfffe0000, "ARIN" },
	{ 0xc06e0000, 0xffffe000, "ARIN" },
	{ 0xc06e8000, 0xffff8000, "ARIN" },
	{ 0xc06f0000, 0xffff8000, "ARIN" },
	{ 0xc06fa000, 0xffffe000, "ARIN" },
	{ 0xc06fc000, 0xffffc000, "ARIN" },
	{ 0xc0700000, 0xfffe0000, "ARIN" },
	{ 0xc0770000, 0xffffe000, "ARIN" },
	{ 0xc0780000, 0xffffe000, "ARIN" },
	{ 0xc078c000, 0xffffe000, "ARIN" },
	{ 0xc07a0000, 0xffffe000, "ARIN" },
	{ 0xc07a8000, 0xffff8000, "ARIN" },
	{ 0xc07b0000, 0xffff0000, "ARIN" },
	{ 0xc07c0000, 0xfffe0000, "ARIN" },
	{ 0xc07e0000, 0xffffe000, "ARIN" },
	{ 0xc07e4000, 0xffffe000, "ARIN" },
	{ 0xc07f0000, 0xffff0000, "ARIN" },
	{ 0xc0800000, 0xffff0000, "ARIN" },
	{ 0xc0810000, 0xffff8000, "ARIN" },
	{ 0xc0820000, 0xffff0000, "ARIN" },
	{ 0xc0830000, 0xffff8000, "ARIN" },
	{ 0xc0838000, 0xffffe000, "ARIN" },
	{ 0xc083e000, 0xffffe000, "ARIN" },
	{ 0xc0840000, 0xffff8000, "ARIN" },
	{ 0xc084c000, 0xffffc000, "ARIN" },
	{ 0xc0850000, 0xffff8000, "ARIN" },
	{ 0xc0858000, 0xffffe000, "ARIN" },
	{ 0xc085e000, 0xffffe000, "ARIN" },
	{ 0xc0860000, 0xfffe0000, "ARIN" },
	{ 0xc0880000, 0xffff8000, "ARIN" },
	{ 0xc0888000, 0xffffe000, "ARIN" },
	{ 0xc0890000, 0xffff0000, "ARIN" },
	{ 0xc08a0000, 0xffffe000, "ARIN" },
	{ 0xc08a4000, 0xffffc000, "ARIN" },
	{ 0xc08a8000, 0xffff8000, "ARIN" },
	{ 0xc08b0000, 0xffff0000, "ARIN" },
	{ 0xc08c0000, 0xffffe000, "ARIN" },
	{ 0xc0920000, 0xffffe000, "ARIN" },
	{ 0xc0926000, 0xffffe000, "ARIN" },
	{ 0xc0928000, 0xffff8000, "ARIN" },
	{ 0xc0930000, 0xffff0000, "ARIN" },
	{ 0xc0940000, 0xffff8000, "ARIN" },
	{ 0xc094a000, 0xffffe000, "ARIN" },
	{ 0xc094c000, 0xffffc000, "ARIN" },
	{ 0xc0950000, 0xffff8000, "ARIN" },
	{ 0xc0958000, 0xffffe000, "ARIN" },
	{ 0xc095c000, 0xffffc000, "ARIN" },
	{ 0xc0960000, 0xffff0000, "ARIN" },
	{ 0xc0970000, 0xffff8000, "ARIN" },
	{ 0xc0978000, 0xffffe000, "ARIN" },
	{ 0xc0980000, 0xfffe0000, "ARIN" },
	{ 0xc09a0000, 0xffff8000, "ARIN" },
	{ 0xc09a8000, 0xffffe000, "ARIN" },
	{ 0xc09b0000, 0xffffc000, "ARIN" },
	{ 0xc09b4000, 0xffffe000, "ARIN" },
	{ 0xc09b8000, 0xffffe000, "ARIN" },
	{ 0xc09c0000, 0xffffe000, "ARIN" },
	{ 0xc09c4000, 0xffffc000, "ARIN" },
	{ 0xc09c8000, 0xffff8000, "ARIN" },
	{ 0xc09d0000, 0xffffc000, "ARIN" },
	{ 0xc09d4000, 0xffffe000, "ARIN" },
	{ 0xc09d8000, 0xffffc000, "ARIN" },
	{ 0xc09e0000, 0xffff8000, "ARIN" },
	{ 0xc09ec000, 0xffffc000, "ARIN" },
	{ 0xc09f0000, 0xffff8000, "ARIN" },
	{ 0xc09f8000, 0xffffe000, "ARIN" },
	{ 0xc0a00000, 0xffff0000, "ARIN" },
	{ 0xc0a10000, 0xffffc000, "ARIN" },
	{ 0xc0a14000, 0xffffe000, "ARIN" },
	{ 0xc0a18000, 0xffffe000, "ARIN" },
	{ 0xc0a30000, 0xffffc000, "ARIN" },
	{ 0xc0a90000, 0xffffc000, "ARIN" },
	{ 0xc0a94000, 0xffffe000, "ARIN" },
	{ 0xc0aa0000, 0xffff8000, "ARIN" },
	{ 0xc0ab0000, 0xffffe000, "ARIN" },
	{ 0xc0ab4000, 0xffffe000, "ARIN" },
	{ 0xc0ab8000, 0xffffc000, "ARIN" },
	{ 0xc0abc000, 0xffffe000, "ARIN" },
	{ 0xc0ac0000, 0xffffe000, "ARIN" },
	{ 0xc0acc000, 0xffffc000, "ARIN" },
	{ 0xc0ad0000, 0xffffc000, "ARIN" },
	{ 0xc0ad8000, 0xffffe000, "ARIN" },
	{ 0xc0ae0000, 0xffffc000, "ARIN" },
	{ 0xc0ae4000, 0xffffe000, "ARIN" },
	{ 0xc0ae8000, 0xffffe000, "ARIN" },
	{ 0xc0af0000, 0xffffc000, "ARIN" },
	{ 0xc0af4000, 0xffffe000, "ARIN" },
	{ 0xc0af8000, 0xffff8000, "ARIN" },
	{ 0xc0b80000, 0xffffe000, "ARIN" },
	{ 0xc0bb0000, 0xffffc000, "ARIN" },
	{ 0xc0bb4000, 0xffffe000, "ARIN" },
	{ 0xc0bb8000, 0xffffc000, "ARIN" },
	{ 0xc0bc0000, 0xfffc0000, "ARIN" },
	{ 0xc0c00000, 0xfffc0000, "ARIN" },
	{ 0xc0c40000, 0xffffe000, "ARIN" },
	{ 0xc0c50000, 0xffff0000, "ARIN" },
	{ 0xc0c60000, 0xffffc000, "ARIN" },
	{ 0xc0c64000, 0xffffe000, "ARIN" },
	{ 0xc0c68000, 0xffffe000, "ARIN" },
	{ 0xc0c70000, 0xffff8000, "ARIN" },
	{ 0xc0c78000, 0xffffe000, "ARIN" },
	{ 0xc0c80000, 0xffffc000, "ARIN" },
	{ 0xc0c84000, 0xffffe000, "ARIN" },
	{ 0xc0c88000, 0xffffe000, "ARIN" },
	{ 0xc0c90000, 0xffff0000, "ARIN" },
	{ 0xc0ca0000, 0xfffe0000, "ARIN" },
	{ 0xc0cc0000, 0xfffc0000, "ARIN" },
	{ 0xc0d00000, 0xffffc000, "ARIN" },
	{ 0xc0d04000, 0xffffe000, "ARIN" },
	{ 0xc0d08000, 0xffffe000, "ARIN" },
	{ 0xc0d10000, 0xffff0000, "ARIN" },
	{ 0xc0d20000, 0xffff8000, "ARIN" },
	{ 0xc0d30000, 0xffffc000, "ARIN" },
	{ 0xc0d34000, 0xffffe000, "ARIN" },
	{ 0xc0d40000, 0xfffe0000, "ARIN" },
	{ 0xc0d70000, 0xffff0000, "ARIN" },
	{ 0xc0d80000, 0xfffe0000, "ARIN" },
	{ 0xc0da0000, 0xffff0000, "ARIN" },
	{ 0xc0db0000, 0xffff8000, "ARIN" },
	{ 0xc0dbc000, 0xffffc000, "ARIN" },
	{ 0xc0dc0000, 0xfffe0000, "ARIN" },
	{ 0xc0de0000, 0xffff8000, "ARIN" },
	{ 0xc0df0000, 0xffff0000, "ARIN" },
	{ 0xc0e00000, 0xffff0000, "ARIN" },
	{ 0xc0e10000, 0xffffc000, "ARIN" },
	{ 0xc0e14000, 0xffffe000, "ARIN" },
	{ 0xc0e18000, 0xffffe000, "ARIN" },
	{ 0xc0e20000, 0xffff8000, "ARIN" },
	{ 0xc0e30000, 0xffff8000, "ARIN" },
	{ 0xc0e40000, 0xffffc000, "ARIN" },
	{ 0xc0e44000, 0xffffe000, "ARIN" },
	{ 0xc0e48000, 0xffff8000, "ARIN" },
	{ 0xc0e50000, 0xffffc000, "ARIN" },
	{ 0xc0e60000, 0xffffe000, "ARIN" },
	{ 0xc0e70000, 0xffff0000, "ARIN" },
	{ 0xc0e80000, 0xffff8000, "ARIN" },
	{ 0xc0e88000, 0xffffe000, "ARIN" },
	{ 0xc0e90000, 0xffff0000, "ARIN" },
	{ 0xc0ea0000, 0xffff0000, "ARIN" },
	{ 0xc0eb0000, 0xffffc000, "ARIN" },
	{ 0xc0ec0000, 0xffffc000, "ARIN" },
	{ 0xc0ed0000, 0xffff8000, "ARIN" },
	{ 0xc0ee0000, 0xffff8000, "ARIN" },
	{ 0xc0ef0000, 0xffff0000, "ARIN" },
	{ 0xc0f00000, 0xffffc000, "ARIN" },
	{ 0xc0f04000, 0xffffe000, "ARIN" },
	{ 0xc0f08000, 0xffffe000, "ARIN" },
	{ 0xc0f10000, 0xffffc000, "ARIN" },
	{ 0xc0f20000, 0xffff0000, "ARIN" },
	{ 0xc0f30000, 0xffffc000, "ARIN" },
	{ 0xc0f38000, 0xffffc000, "ARIN" },
	{ 0xc0f40000, 0xfffe0000, "ARIN" },
	{ 0xc0f60000, 0xffff0000, "ARIN" },
	{ 0xc0f70000, 0xffffc000, "ARIN" },
	{ 0xc0f74000, 0xffffe000, "ARIN" },
	{ 0xc0f78000, 0xffff8000, "ARIN" },
	{ 0xc0f80000, 0xffff0000, "ARIN" },
	{ 0xc0f90000, 0xffffc000, "ARIN" },
	{ 0xc0fa0000, 0xffff8000, "ARIN" },
	{ 0xc0fb0000, 0xffff0000, "ARIN" },
	{ 0xc0fc0000, 0xffff8000, "ARIN" },
	{ 0xc0fd0000, 0xffffe000, "ARIN" },
	{ 0xc0fe0000, 0xffffc000, "ARIN" },
	{ 0xc4010000, 0xffff8000, "ARIN" },
	{ 0xc4018000, 0xffffc000, "ARIN" },
	{ 0xc4020000, 0xffffc000, "ARIN" },
	{ 0xc4024000, 0xffffe000, "ARIN" },
	{ 0xc4028000, 0xffffe000, "ARIN" },
	{ 0xc4030000, 0xffff0000, "ARIN" },
	{ 0xc4040000, 0xfffc0000, "ARIN" },
	{ 0xc4080000, 0xfffc0000, "ARIN" },
	{ 0xc40c0000, 0xffff8000, "ARIN" },
	{ 0xc40ca000, 0xffffe000, "ARIN" },
	{ 0xc40d0000, 0xffff0000, "ARIN" },
	{ 0xc40e0000, 0xfffe0000, "ARIN" },
	{ 0xc4100000, 0xfffc0000, "ARIN" },
	{ 0xc4140000, 0xffffe000, "ARIN" },
	{ 0xc4150000, 0xffff0000, "ARIN" },
	{ 0xc4160000, 0xffff8000, "ARIN" },
	{ 0xc4168000, 0xffffc000, "ARIN" },
	{ 0xc416c000, 0xffffe000, "ARIN" },
	{ 0xc4170000, 0xffff0000, "ARIN" },
	{ 0xc4180000, 0xfffe0000, "ARIN" },
	{ 0xc41a0000, 0xffff0000, "ARIN" },
	{ 0xc41b0000, 0xffffc000, "ARIN" },
	{ 0xc41c0000, 0xffff8000, "ARIN" },
	{ 0xc41c8000, 0xffffc000, "ARIN" },
	{ 0xc41d0000, 0xffffc000, "ARIN" },
	{ 0xc41d4000, 0xffffe000, "ARIN" },
	{ 0xc41d8000, 0xffffe000, "ARIN" },
	{ 0xc41dc000, 0xffffc000, "ARIN" },
	{ 0xc41e0000, 0xfffe0000, "ARIN" },
	{ 0xc4200000, 0xffffc000, "ARIN" },
	{ 0xc4204000, 0xffffe000, "ARIN" },
	{ 0xc4208000, 0xffffe000, "ARIN" },
	{ 0xc4210000, 0xffff0000, "ARIN" },
	{ 0xc4220000, 0xfffe0000, "ARIN" },
	{ 0xc4240000, 0xfffe0000, "ARIN" },
	{ 0xc4280000, 0xffffc000, "ARIN" },
	{ 0xc4290000, 0xffffc000, "ARIN" },
	{ 0xc4294000, 0xffffe000, "ARIN" },
	{ 0xc4298000, 0xffffc000, "ARIN" },
	{ 0xc429c000, 0xffffe000, "ARIN" },
	{ 0xc42a0000, 0xffffc000, "ARIN" },
	{ 0xc42b0000, 0xffffc000, "ARIN" },
	{ 0xc42c0000, 0xffffc000, "ARIN" },
	{ 0xc42c4000, 0xffffe000, "ARIN" },
	{ 0xc42c8000, 0xffff8000, "ARIN" },
	{ 0xc4d80000, 0xffffe000, "ARIN" },
	{ 0xc6010000, 0xffffc000, "ARIN" },
	{ 0xc6020000, 0xffffe000, "ARIN" },
	{ 0xc6030000, 0xffff0000, "ARIN" },
	{ 0xc6040000, 0xfffe0000, "ARIN" },
	{ 0xc6060000, 0xffff0000, "ARIN" },
	{ 0xc6070000, 0xffffc000, "ARIN" },
	{ 0xc6074000, 0xffffe000, "ARIN" },
	{ 0xc6078000, 0xffffc000, "ARIN" },
	{ 0xc607c000, 0xffffe000, "ARIN" },
	{ 0xc6080000, 0xffffc000, "ARIN" },
	{ 0xc6084000, 0xffffe000, "ARIN" },
	{ 0xc6088000, 0xffff8000, "ARIN" },
	{ 0xc6090000, 0xffff0000, "ARIN" },
	{ 0xc60a0000, 0xffff0000, "ARIN" },
	{ 0xc60b0000, 0xffffc000, "ARIN" },
	{ 0xc60b4000, 0xffffe000, "ARIN" },
	{ 0xc60c0000, 0xffffc000, "ARIN" },
	{ 0xc60d0000, 0xffffc000, "ARIN" },
	{ 0xc60d4000, 0xffffe000, "ARIN" },
	{ 0xc60e0000, 0xffff8000, "ARIN" },
	{ 0xc60e8000, 0xffffc000, "ARIN" },
	{ 0xc60f0000, 0xffffc000, "ARIN" },
	{ 0xc6100000, 0xffffe000, "ARIN" },
	{ 0xc6110000, 0xffff0000, "ARIN" },
	{ 0xc6120000, 0xfffe0000, "ARIN" },
	{ 0xc6140000, 0xffffc000, "ARIN" },
	{ 0xc6150000, 0xffffc000, "ARIN" },
	{ 0xc6160000, 0xffff0000, "ARIN" },
	{ 0xc6170000, 0xffffc000, "ARIN" },
	{ 0xc6180000, 0xffffe000, "ARIN" },
	{ 0xc6190000, 0xffff0000, "ARIN" },
	{ 0xc61b0000, 0xffffc000, "ARIN" },
	{ 0xc61c0000, 0xffff0000, "ARIN" },
	{ 0xc61d0000, 0xffff8000, "ARIN" },
	{ 0xc61d8000, 0xffffc000, "ARIN" },
	{ 0xc61e0000, 0xfffe0000, "ARIN" },
	{ 0xc6200000, 0xfffe0000, "ARIN" },
	{ 0xc6230000, 0xffffc000, "ARIN" },
	{ 0xc6234000, 0xffffe000, "ARIN" },
	{ 0xc6238000, 0xffff8000, "ARIN" },
	{ 0xc6240000, 0xffffc000, "ARIN" },
	{ 0xc6244000, 0xffffe000, "ARIN" },
	{ 0xc6248000, 0xffff8000, "ARIN" },
	{ 0xc6250000, 0xffffc000, "ARIN" },
	{ 0xc6254000, 0xffffe000, "ARIN" },
	{ 0xc6258000, 0xffffe000, "ARIN" },
	{ 0xc6260000, 0xffffc000, "ARIN" },
	{ 0xc6264000, 0xffffe000, "ARIN" },
	{ 0xc6268000, 0xffff8000, "ARIN" },
	{ 0xc6270000, 0xffff0000, "ARIN" },
	{ 0xc6280000, 0xffff8000, "ARIN" },
	{ 0xc6290000, 0xffffc000, "ARIN" },
	{ 0xc6294000, 0xffffe000, "ARIN" },
	{ 0xc62a0000, 0xfffe0000, "ARIN" },
	{ 0xc62d0000, 0xffffc000, "ARIN" },
	{ 0xc62d4000, 0xffffe000, "ARIN" },
	{ 0xc62e0000, 0xffffc000, "ARIN" },
	{ 0xc62e4000, 0xffffe000, "ARIN" },
	{ 0xc62f0000, 0xffffc000, "ARIN" },
	{ 0xc62f4000, 0xffffe000, "ARIN" },
	{ 0xc6300000, 0xffffc000, "ARIN" },
	{ 0xc6304000, 0xffffe000, "ARIN" },
	{ 0xc6310000, 0xffff0000, "ARIN" },
	{ 0xc6320000, 0xffffc000, "ARIN" },
	{ 0xc6324000, 0xffffe000, "ARIN" },
	{ 0xc6330000, 0xffff0000, "ARIN" },
	{ 0xc6340000, 0xffffc000, "ARIN" },
	{ 0xc6344000, 0xffffe000, "ARIN" },
	{ 0xc6350000, 0xffff0000, "ARIN" },
	{ 0xc6360000, 0xffff0000, "ARIN" },
	{ 0xc6370000, 0xffffc000, "ARIN" },
	{ 0xc6374000, 0xffffe000, "ARIN" },
	{ 0xc6378000, 0xffffc000, "ARIN" },
	{ 0xc6380000, 0xffff8000, "ARIN" },
	{ 0xc6390000, 0xffffc000, "ARIN" },
	{ 0xc6394000, 0xffffe000, "ARIN" },
	{ 0xc63a0000, 0xffffc000, "ARIN" },
	{ 0xc63a4000, 0xffffe000, "ARIN" },
	{ 0xc63b0000, 0xffff0000, "ARIN" },
	{ 0xc63d0000, 0xffffc000, "ARIN" },
	{ 0xc63d4000, 0xffffe000, "ARIN" },
	{ 0xc63e0000, 0xfffe0000, "ARIN" },
	{ 0xc6430000, 0xffff0000, "ARIN" },
	{ 0xc6470000, 0xffffc000, "ARIN" },
	{ 0xc6474000, 0xffffe000, "ARIN" },
	{ 0xc6480000, 0xffffc000, "ARIN" },
	{ 0xc6484000, 0xffffe000, "ARIN" },
	{ 0xc6490000, 0xffff0000, "ARIN" },
	{ 0xc64a0000, 0xffffc000, "ARIN" },
	{ 0xc64a4000, 0xffffe000, "ARIN" },
	{ 0xc64a8000, 0xffffc000, "ARIN" },
	{ 0xc64b0000, 0xffff0000, "ARIN" },
	{ 0xc64c0000, 0xfffc0000, "ARIN" },
	{ 0xc6500000, 0xfffc0000, "ARIN" },
	{ 0xc6540000, 0xffffc000, "ARIN" },
	{ 0xc6550000, 0xffff0000, "ARIN" },
	{ 0xc6560000, 0xfffe0000, "ARIN" },
	{ 0xc6590000, 0xffffc000, "ARIN" },
	{ 0xc6594000, 0xffffe000, "ARIN" },
	{ 0xc6598000, 0xffffc000, "ARIN" },
	{ 0xc65a0000, 0xffffc000, "ARIN" },
	{ 0xc65a4000, 0xffffe000, "ARIN" },
	{ 0xc65a8000, 0xffff8000, "ARIN" },
	{ 0xc65b0000, 0xffffc000, "ARIN" },
	{ 0xc65b4000, 0xffffe000, "ARIN" },
	{ 0xc65c0000, 0xfffc0000, "ARIN" },
	{ 0xc6600000, 0xfffe0000, "ARIN" },
	{ 0xc6620000, 0xffffc000, "ARIN" },
	{ 0xc6624000, 0xffffe000, "ARIN" },
	{ 0xc6628000, 0xffffe000, "ARIN" },
	{ 0xc6630000, 0xffff0000, "ARIN" },
	{ 0xc6640000, 0xffffc000, "ARIN" },
	{ 0xc6644000, 0xffffe000, "ARIN" },
	{ 0xc6648000, 0xffffe000, "ARIN" },
	{ 0xc6650000, 0xffffc000, "ARIN" },
	{ 0xc6660000, 0xfffe0000, "ARIN" },
	{ 0xc6680000, 0xffff0000, "ARIN" },
	{ 0xc6690000, 0xffffc000, "ARIN" },
	{ 0xc6694000, 0xffffe000, "ARIN" },
	{ 0xc6698000, 0xffffe000, "ARIN" },
	{ 0xc669c000, 0xffffc000, "ARIN" },
	{ 0xc66a0000, 0xfffe0000, "ARIN" },
	{ 0xc66c0000, 0xfffc0000, "ARIN" },
	{ 0xc6700000, 0xfff80000, "ARIN" },
	{ 0xc67c0000, 0xfffc0000, "ARIN" },
	{ 0xc6800000, 0xfffc0000, "ARIN" },
	{ 0xc6840000, 0xfffe0000, "ARIN" },
	{ 0xc6860000, 0xffffc000, "ARIN" },
	{ 0xc6864000, 0xffffe000, "ARIN" },
	{ 0xc6868000, 0xffff8000, "ARIN" },
	{ 0xc6870000, 0xffff0000, "ARIN" },
	{ 0xc6880000, 0xfffc0000, "ARIN" },
	{ 0xc68c0000, 0xffffc000, "ARIN" },
	{ 0xc68c4000, 0xffffe000, "ARIN" },
	{ 0xc68c8000, 0xffff8000, "ARIN" },
	{ 0xc68d0000, 0xffff0000, "ARIN" },
	{ 0xc68e0000, 0xffff0000, "ARIN" },
	{ 0xc68f0000, 0xffffe000, "ARIN" },
	{ 0xc68f4000, 0xffffe000, "ARIN" },
	{ 0xc68f8000, 0xffffe000, "ARIN" },
	{ 0xc68fc000, 0xffffc000, "ARIN" },
	{ 0xc6900000, 0xfffc0000, "ARIN" },
	{ 0xc6940000, 0xffffc000, "ARIN" },
	{ 0xc6944000, 0xffffe000, "ARIN" },
	{ 0xc6948000, 0xffff8000, "ARIN" },
	{ 0xc6950000, 0xffff0000, "ARIN" },
	{ 0xc6960000, 0xfffe0000, "ARIN" },
	{ 0xc6980000, 0xffff0000, "ARIN" },
	{ 0xc6990000, 0xffffc000, "ARIN" },
	{ 0xc6994000, 0xffffe000, "ARIN" },
	{ 0xc6998000, 0xffff8000, "ARIN" },
	{ 0xc69a0000, 0xffffc000, "ARIN" },
	{ 0xc69a4000, 0xffffe000, "ARIN" },
	{ 0xc69a8000, 0xffffe000, "ARIN" },
	{ 0xc69b0000, 0xffff0000, "ARIN" },
	{ 0xc69c0000, 0xfffc0000, "ARIN" },
	{ 0xc6a00000, 0xfffc0000, "ARIN" },
	{ 0xc6a40000, 0xfffe0000, "ARIN" },
	{ 0xc6a60000, 0xffff0000, "ARIN" },
	{ 0xc6a70000, 0xffffc000, "ARIN" },
	{ 0xc6a78000, 0xffffc000, "ARIN" },
	{ 0xc6a7e000, 0xffffe000, "ARIN" },
	{ 0xc6a80000, 0xfffc0000, "ARIN" },
	{ 0xc6ae0000, 0xffff0000, "ARIN" },
	{ 0xc6af0000, 0xffffc000, "ARIN" },
	{ 0xc6af4000, 0xffffe000, "ARIN" },
	{ 0xc6af8000, 0xffff8000, "ARIN" },
	{ 0xc6b00000, 0xffff0000, "ARIN" },
	{ 0xc6b10000, 0xffffc000, "ARIN" },
	{ 0xc6b14000, 0xffffe000, "ARIN" },
	{ 0xc6b18000, 0xffff8000, "ARIN" },
	{ 0xc6b20000, 0xffffc000, "ARIN" },
	{ 0xc6b24000, 0xffffe000, "ARIN" },
	{ 0xc6b28000, 0xffff8000, "ARIN" },
	{ 0xc6b30000, 0xffffc000, "ARIN" },
	{ 0xc6b38000, 0xffff8000, "ARIN" },
	{ 0xc6b40000, 0xffff0000, "ARIN" },
	{ 0xc6b50000, 0xffffc000, "ARIN" },
	{ 0xc6b54000, 0xffffe000, "ARIN" },
	{ 0xc6b58000, 0xffff8000, "ARIN" },
	{ 0xc6b60000, 0xfffe0000, "ARIN" },
	{ 0xc6b80000, 0xfffc0000, "ARIN" },
	{ 0xc6bc0000, 0xfffe0000, "ARIN" },
	{ 0xc6be0000, 0xffffc000, "ARIN" },
	{ 0xc6be8000, 0xffff8000, "ARIN" },
	{ 0xc6bf0000, 0xffff0000, "ARIN" },
	{ 0xc6c00000, 0xfffc0000, "ARIN" },
	{ 0xc6c40000, 0xfffe0000, "ARIN" },
	{ 0xc6c60000, 0xffff0000, "ARIN" },
	{ 0xc6c70000, 0xffffc000, "ARIN" },
	{ 0xc6c78000, 0xffff8000, "ARIN" },
	{ 0xc6c80000, 0xffffe000, "ARIN" },
	{ 0xc6c88000, 0xffff8000, "ARIN" },
	{ 0xc6c90000, 0xffff0000, "ARIN" },
	{ 0xc6ca0000, 0xfffe0000, "ARIN" },
	{ 0xc6cc0000, 0xffff8000, "ARIN" },
	{ 0xc6cc8000, 0xffffc000, "ARIN" },
	{ 0xc6cd0000, 0xffffc000, "ARIN" },
	{ 0xc6cd4000, 0xffffe000, "ARIN" },
	{ 0xc6cd8000, 0xffff8000, "ARIN" },
	{ 0xc6ce0000, 0xfffe0000, "ARIN" },
	{ 0xc6d00000, 0xfffe0000, "ARIN" },
	{ 0xc6d20000, 0xffffc000, "ARIN" },
	{ 0xc6d28000, 0xffff8000, "ARIN" },
	{ 0xc6d30000, 0xffff8000, "ARIN" },
	{ 0xc6d38000, 0xffffe000, "ARIN" },
	{ 0xc6d3c000, 0xffffc000, "ARIN" },
	{ 0xc6d40000, 0xfffc0000, "ARIN" },
	{ 0xc6d80000, 0xffff0000, "ARIN" },
	{ 0xc6d90000, 0xffffc000, "ARIN" },
	{ 0xc6d94000, 0xffffe000, "ARIN" },
	{ 0xc6d98000, 0xffff8000, "ARIN" },
	{ 0xc6da0000, 0xfffe0000, "ARIN" },
	{ 0xc6dc0000, 0xfffc0000, "ARIN" },
	{ 0xc6e00000, 0xfff80000, "ARIN" },
	{ 0xc6e80000, 0xffffc000, "ARIN" },
	{ 0xc6e84000, 0xffffe000, "ARIN" },
	{ 0xc6e88000, 0xffff8000, "ARIN" },
	{ 0xc6e90000, 0xffff0000, "ARIN" },
	{ 0xc6ea0000, 0xfffe0000, "ARIN" },
	{ 0xc6ec0000, 0xfffc0000, "ARIN" },
	{ 0xc6f00000, 0xffff8000, "ARIN" },
	{ 0xc6f08000, 0xffffe000, "ARIN" },
	{ 0xc6f10000, 0xffff0000, "ARIN" },
	{ 0xc6f20000, 0xfffe0000, "ARIN" },
	{ 0xc6f40000, 0xffffc000, "ARIN" },
	{ 0xc6f48000, 0xffff8000, "ARIN" },
	{ 0xc6f50000, 0xffffc000, "ARIN" },
	{ 0xc6f58000, 0xffff8000, "ARIN" },
	{ 0xc6f60000, 0xfffe0000, "ARIN" },
	{ 0xc6f80000, 0xfffe0000, "ARIN" },
	{ 0xc6fa0000, 0xffff0000, "ARIN" },
	{ 0xc6fb0000, 0xffffc000, "ARIN" },
	{ 0xc6fc0000, 0xfffe0000, "ARIN" },
	{ 0xc6fe0000, 0xffffc000, "ARIN" },
	{ 0xc7000000, 0xff000000, "ARIN" },
	{ 0xc8000000, 0xff000000, "ARIN" },
	{ 0xcc000000, 0xfc000000, "ARIN" },
	{ 0xd0000000, 0xfe000000, "ARIN" },
	{ 0xd6000000, 0xfe000000, "ARIN" },
	{ 0xd8000000, 0xff000000, "ARIN" },
	{ 0x00000000, 0xfe000000, "IANA" },
	{ 0x02000000, 0xff000000, "IANA" },
	{ 0x05000000, 0xff000000, "IANA" },
	{ 0x07000000, 0xff000000, "IANA" },
	{ 0x0a000000, 0xff000000, "IANA" },
	{ 0x0e000000, 0xff000000, "IANA" },
	{ 0x17000000, 0xff000000, "IANA" },
	{ 0x1b000000, 0xff000000, "IANA" },
	{ 0x1f000000, 0xff000000, "IANA" },
	{ 0x24000000, 0xfe000000, "IANA" },
	{ 0x27000000, 0xff000000, "IANA" },
	{ 0x29000000, 0xff000000, "IANA" },
	{ 0x2a000000, 0xff000000, "IANA" },
	{ 0x3a000000, 0xfe000000, "IANA" },
	{ 0x3c000000, 0xff000000, "IANA" },
	{ 0x45000000, 0xff000000, "IANA" },
	{ 0x46000000, 0xfe000000, "IANA" },
	{ 0x48000000, 0xf8000000, "IANA" },
	{ 0x52000000, 0xfe000000, "IANA" },
	{ 0x54000000, 0xfc000000, "IANA" },
	{ 0x58000000, 0xf8000000, "IANA" },
	{ 0x60000000, 0xe0000000, "IANA" },
	{ 0xa9fe0000, 0xffff0000, "IANA" },
	{ 0xac100000, 0xfff00000, "IANA" },
	{ 0xc0a80000, 0xffff0000, "IANA" },
	{ 0xc5000000, 0xff000000, "IANA" },
	{ 0xde000000, 0xfe000000, "IANA" },
	{ 0xe0000000, 0xe0000000, "IANA" },

};
